Module: Google::Apis::GkebackupV1
- Defined in:
- lib/google/apis/gkebackup_v1.rb,
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/service.rb,
lib/google/apis/gkebackup_v1/gem_version.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
Backup for GKE API
Backup for GKE is a managed Kubernetes workload backup and restore service for GKE clusters.
Defined Under Namespace
Classes: AuditConfig, AuditLogConfig, Backup, BackupChannel, BackupConfig, BackupConfigDetails, BackupPlan, BackupPlanBinding, BackupPlanDetails, BackupforGKEService, Binding, ClusterMetadata, ClusterResourceRestoreScope, Date, DayOfWeekList, Empty, EncryptionKey, ExclusionWindow, Expr, Filter, GetBackupIndexDownloadUrlResponse, GoogleLongrunningCancelOperationRequest, GoogleLongrunningListOperationsResponse, GoogleLongrunningOperation, GoogleRpcStatus, GroupKind, GroupKindDependency, Label, ListBackupChannelsResponse, ListBackupPlanBindingsResponse, ListBackupPlansResponse, ListBackupsResponse, ListLocationsResponse, ListRestoreChannelsResponse, ListRestorePlanBindingsResponse, ListRestorePlansResponse, ListRestoresResponse, ListVolumeBackupsResponse, ListVolumeRestoresResponse, Location, NamespacedName, NamespacedNames, Namespaces, OperationMetadata, Policy, ResourceFilter, ResourceLabels, ResourceSelector, Restore, RestoreChannel, RestoreConfig, RestoreOrder, RestorePlan, RestorePlanBinding, RetentionPolicy, RetentionPolicyDetails, RpoConfig, Schedule, SetIamPolicyRequest, SubstitutionRule, TestIamPermissionsRequest, TestIamPermissionsResponse, TimeOfDay, TransformationRule, TransformationRuleAction, TroubleshootingInfo, VolumeBackup, VolumeDataRestorePolicyBinding, VolumeDataRestorePolicyOverride, VolumeRestore
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-gkebackup_v1 gem
"0.54.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.18.0"- REVISION =
Revision of the discovery document this client was generated from
"20251209"- VERSION =
Version of the Backup for GKE API this client connects to. This is NOT the gem version.
'V1'- AUTH_CLOUD_PLATFORM =
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
'https://www.googleapis.com/auth/cloud-platform'