Class: Google::Apis::GkebackupV1::BackupConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

BackupConfig defines the configuration of Backups created via this BackupPlan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupConfig

Returns a new instance of BackupConfig.



744
745
746
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_namespacesBoolean Also known as: all_namespaces?

If True, include all namespaced resources Corresponds to the JSON property allNamespaces

Returns:

  • (Boolean)


698
699
700
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 698

def all_namespaces
  @all_namespaces
end

#encryption_keyGoogle::Apis::GkebackupV1::EncryptionKey

Defined a customer managed encryption key that will be used to encrypt Backup artifacts. Corresponds to the JSON property encryptionKey



705
706
707
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 705

def encryption_key
  @encryption_key
end

#include_secretsBoolean Also known as: include_secrets?

Optional. This flag specifies whether Kubernetes Secret resources should be included when they fall into the scope of Backups. Default: False Corresponds to the JSON property includeSecrets

Returns:

  • (Boolean)


711
712
713
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 711

def include_secrets
  @include_secrets
end

#include_volume_dataBoolean Also known as: include_volume_data?

Optional. This flag specifies whether volume data should be backed up when PVCs are included in the scope of a Backup. Default: False Corresponds to the JSON property includeVolumeData

Returns:

  • (Boolean)


718
719
720
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 718

def include_volume_data
  @include_volume_data
end

#permissive_modeBoolean Also known as: permissive_mode?

Optional. If false, Backups will fail when Backup for GKE detects Kubernetes configuration that is non-standard or requires additional setup to restore. Default: False Corresponds to the JSON property permissiveMode

Returns:

  • (Boolean)


726
727
728
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 726

def permissive_mode
  @permissive_mode
end

#selected_applicationsGoogle::Apis::GkebackupV1::NamespacedNames

A list of namespaced Kubernetes resources. Corresponds to the JSON property selectedApplications



732
733
734
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 732

def selected_applications
  @selected_applications
end

#selected_namespace_labelsGoogle::Apis::GkebackupV1::ResourceLabels

A list of Kubernetes labels. Corresponds to the JSON property selectedNamespaceLabels



737
738
739
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 737

def selected_namespace_labels
  @selected_namespace_labels
end

#selected_namespacesGoogle::Apis::GkebackupV1::Namespaces

A list of Kubernetes Namespaces. Corresponds to the JSON property selectedNamespaces



742
743
744
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 742

def selected_namespaces
  @selected_namespaces
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



749
750
751
752
753
754
755
756
757
758
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 749

def update!(**args)
  @all_namespaces = args[:all_namespaces] if args.key?(:all_namespaces)
  @encryption_key = args[:encryption_key] if args.key?(:encryption_key)
  @include_secrets = args[:include_secrets] if args.key?(:include_secrets)
  @include_volume_data = args[:include_volume_data] if args.key?(:include_volume_data)
  @permissive_mode = args[:permissive_mode] if args.key?(:permissive_mode)
  @selected_applications = args[:selected_applications] if args.key?(:selected_applications)
  @selected_namespace_labels = args[:selected_namespace_labels] if args.key?(:selected_namespace_labels)
  @selected_namespaces = args[:selected_namespaces] if args.key?(:selected_namespaces)
end