Class: Google::Apis::GkebackupV1::BackupPlanBinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

A BackupPlanBinding binds a BackupPlan with a BackupChannel. This resource is created automatically when a BackupPlan is created using a BackupChannel. This also serves as a holder for cross-project fields that need to be displayed in the current project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupPlanBinding

Returns a new instance of BackupPlanBinding.



1058
1059
1060
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1058

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_planString

Output only. Immutable. The fully qualified name of the BackupPlan bound with the parent BackupChannel. projects/*/locations/*/backupPlans/backup_plan` Corresponds to the JSON propertybackupPlan`

Returns:

  • (String)


1010
1011
1012
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1010

def backup_plan
  @backup_plan
end

#backup_plan_detailsGoogle::Apis::GkebackupV1::BackupPlanDetails

Contains metadata about the backup plan/backup. Corresponds to the JSON property backupPlanDetails



1015
1016
1017
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1015

def backup_plan_details
  @backup_plan_details
end

#clusterString

Output only. Immutable. The fully qualified name of the cluster that is being backed up Valid formats: - projects/*/locations/*/clusters/* - projects/*/ zones/*/clusters/* Corresponds to the JSON property cluster

Returns:

  • (String)


1022
1023
1024
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1022

def cluster
  @cluster
end

#create_timeString

Output only. The timestamp when this binding was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1027
1028
1029
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1027

def create_time
  @create_time
end

#etagString

Output only. etag is used for optimistic concurrency control as a way to help prevent simultaneous updates of a BackupPlanBinding from overwriting each other. It is strongly suggested that systems make use of the 'etag' in the read-modify-write cycle to perform BackupPlanBinding updates in order to avoid race conditions: An etag is returned in the response to GetBackupPlanBinding, and systems are expected to put that etag in the request to UpdateBackupPlanBinding or DeleteBackupPlanBinding to ensure that their change will be applied to the same version of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


1039
1040
1041
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1039

def etag
  @etag
end

#nameString

Identifier. The fully qualified name of the BackupPlanBinding. projects/*/ locations/*/backupChannels/*/backupPlanBindings/* Corresponds to the JSON property name

Returns:

  • (String)


1045
1046
1047
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1045

def name
  @name
end

#uidString

Output only. Server generated global unique identifier of UUID4 Corresponds to the JSON property uid

Returns:

  • (String)


1051
1052
1053
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1051

def uid
  @uid
end

#update_timeString

Output only. The timestamp when this binding was created. Corresponds to the JSON property updateTime

Returns:

  • (String)


1056
1057
1058
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1056

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1063

def update!(**args)
  @backup_plan = args[:backup_plan] if args.key?(:backup_plan)
  @backup_plan_details = args[:backup_plan_details] if args.key?(:backup_plan_details)
  @cluster = args[:cluster] if args.key?(:cluster)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end