Class: Google::Apis::GkebackupV1::BackupPlanDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Contains metadata about the backup plan/backup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupPlanDetails

Returns a new instance of BackupPlanDetails.



1119
1120
1121
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1119

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_config_detailsGoogle::Apis::GkebackupV1::BackupConfigDetails

BackupConfigDetails defines the configuration of Backups created via this BackupPlan. Corresponds to the JSON property backupConfigDetails



1077
1078
1079
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1077

def backup_config_details
  @backup_config_details
end

#last_successful_backupString

Output only. The fully qualified name of the last successful Backup created under this BackupPlan. projects/*/locations/*/backupPlans/*/backups/* Corresponds to the JSON property lastSuccessfulBackup

Returns:

  • (String)


1083
1084
1085
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1083

def last_successful_backup
  @last_successful_backup
end

#last_successful_backup_timeString

Output only. Completion time of the last successful Backup. This is sourced from a successful Backup's complete_time field. Corresponds to the JSON property lastSuccessfulBackupTime

Returns:

  • (String)


1089
1090
1091
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1089

def last_successful_backup_time
  @last_successful_backup_time
end

#next_scheduled_backup_timeString

Output only. Start time of next scheduled backup under this BackupPlan by either cron_schedule or rpo config. This is sourced from BackupPlan. Corresponds to the JSON property nextScheduledBackupTime

Returns:

  • (String)


1095
1096
1097
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1095

def next_scheduled_backup_time
  @next_scheduled_backup_time
end

#protected_pod_countFixnum

Output only. The number of Kubernetes Pods backed up in the last successful Backup created via this BackupPlan. Corresponds to the JSON property protectedPodCount

Returns:

  • (Fixnum)


1101
1102
1103
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1101

def protected_pod_count
  @protected_pod_count
end

#retention_policy_detailsGoogle::Apis::GkebackupV1::RetentionPolicyDetails

RetentionPolicyDetails defines a Backup retention policy for a BackupPlan. Corresponds to the JSON property retentionPolicyDetails



1106
1107
1108
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1106

def retention_policy_details
  @retention_policy_details
end

#rpo_risk_levelFixnum

Output only. A number that represents the current risk level of this BackupPlan from RPO perspective with 1 being no risk and 5 being highest risk. Corresponds to the JSON property rpoRiskLevel

Returns:

  • (Fixnum)


1112
1113
1114
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1112

def rpo_risk_level
  @rpo_risk_level
end

#stateString

Output only. State of the BackupPlan. Corresponds to the JSON property state

Returns:

  • (String)


1117
1118
1119
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1117

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1124

def update!(**args)
  @backup_config_details = args[:backup_config_details] if args.key?(:backup_config_details)
  @last_successful_backup = args[:last_successful_backup] if args.key?(:last_successful_backup)
  @last_successful_backup_time = args[:last_successful_backup_time] if args.key?(:last_successful_backup_time)
  @next_scheduled_backup_time = args[:next_scheduled_backup_time] if args.key?(:next_scheduled_backup_time)
  @protected_pod_count = args[:protected_pod_count] if args.key?(:protected_pod_count)
  @retention_policy_details = args[:retention_policy_details] if args.key?(:retention_policy_details)
  @rpo_risk_level = args[:rpo_risk_level] if args.key?(:rpo_risk_level)
  @state = args[:state] if args.key?(:state)
end