Class: Google::Apis::GkebackupV1::Expr
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::Expr
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
Represents a textual expression in the Common Expression Language (CEL) syntax. CEL is a C-like expression language. The syntax and semantics of CEL are documented at https://github.com/google/cel-spec. Example (Comparison): title: "Summary size limit" description: "Determines if a summary is less than 100 chars" expression: "document.summary.size() < 100" Example (Equality): title: " Requestor is owner" description: "Determines if requestor is the document owner" expression: "document.owner == request.auth.claims.email" Example ( Logic): title: "Public documents" description: "Determine whether the document should be publicly visible" expression: "document.type != 'private' && document.type != 'internal'" Example (Data Manipulation): title: "Notification string" description: "Create a notification string with a timestamp." expression: "'New message received at ' + string(document.create_time)" The exact variables and functions that may be referenced within an expression are determined by the service that evaluates it. See the service documentation for additional information.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#expression ⇒ String
Textual representation of an expression in Common Expression Language syntax.
-
#location ⇒ String
Optional.
-
#title ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Expr
constructor
A new instance of Expr.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Expr
Returns a new instance of Expr.
1586 1587 1588 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1586 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. Description of the expression. This is a longer text which describes
the expression, e.g. when hovered over it in a UI.
Corresponds to the JSON property description
1567 1568 1569 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1567 def description @description end |
#expression ⇒ String
Textual representation of an expression in Common Expression Language syntax.
Corresponds to the JSON property expression
1572 1573 1574 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1572 def expression @expression end |
#location ⇒ String
Optional. String indicating the location of the expression for error reporting,
e.g. a file name and a position in the file.
Corresponds to the JSON property location
1578 1579 1580 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1578 def location @location end |
#title ⇒ String
Optional. Title for the expression, i.e. a short string describing its purpose.
This can be used e.g. in UIs which allow to enter the expression.
Corresponds to the JSON property title
1584 1585 1586 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1584 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1591 1592 1593 1594 1595 1596 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1591 def update!(**args) @description = args[:description] if args.key?(:description) @expression = args[:expression] if args.key?(:expression) @location = args[:location] if args.key?(:location) @title = args[:title] if args.key?(:title) end |