Class: Google::Apis::GkebackupV1::GroupKindDependency

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Defines a dependency between two group kinds.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GroupKindDependency

Returns a new instance of GroupKindDependency.



1906
1907
1908
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1906

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#requiringGoogle::Apis::GkebackupV1::GroupKind

This is a direct map to the Kubernetes GroupKind type GroupKind and is used for identifying specific "types" of resources to restore. Corresponds to the JSON property requiring



1897
1898
1899
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1897

def requiring
  @requiring
end

#satisfyingGoogle::Apis::GkebackupV1::GroupKind

This is a direct map to the Kubernetes GroupKind type GroupKind and is used for identifying specific "types" of resources to restore. Corresponds to the JSON property satisfying



1904
1905
1906
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1904

def satisfying
  @satisfying
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1911
1912
1913
1914
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1911

def update!(**args)
  @requiring = args[:requiring] if args.key?(:requiring)
  @satisfying = args[:satisfying] if args.key?(:satisfying)
end