Class: Google::Apis::GkebackupV1::ResourceFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

ResourceFilter specifies matching criteria to limit the scope of a change to a specific set of kubernetes resources that are selected for restoration from a backup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceFilter

Returns a new instance of ResourceFilter.



2592
2593
2594
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2592

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#group_kindsArray<Google::Apis::GkebackupV1::GroupKind>

Optional. (Filtering parameter) Any resource subject to transformation must belong to one of the listed "types". If this field is not provided, no type filtering will be performed (all resources of all types matching previous filtering parameters will be candidates for transformation). Corresponds to the JSON property groupKinds



2573
2574
2575
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2573

def group_kinds
  @group_kinds
end

#json_pathString

Optional. This is a JSONPath expression that matches specific fields of candidate resources and it operates as a filtering parameter (resources that are not matched with this expression will not be candidates for transformation). Corresponds to the JSON property jsonPath

Returns:

  • (String)


2581
2582
2583
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2581

def json_path
  @json_path
end

#namespacesArray<String>

Optional. (Filtering parameter) Any resource subject to transformation must be contained within one of the listed Kubernetes Namespace in the Backup. If this field is not provided, no namespace filtering will be performed (all resources in all Namespaces, including all cluster-scoped resources, will be candidates for transformation). Corresponds to the JSON property namespaces

Returns:

  • (Array<String>)


2590
2591
2592
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2590

def namespaces
  @namespaces
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2597
2598
2599
2600
2601
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2597

def update!(**args)
  @group_kinds = args[:group_kinds] if args.key?(:group_kinds)
  @json_path = args[:json_path] if args.key?(:json_path)
  @namespaces = args[:namespaces] if args.key?(:namespaces)
end