Class: Google::Apis::GkebackupV1::Restore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Represents both a request to Restore some portion of a Backup into a target GKE cluster and a record of the restore operation itself.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Restore

Returns a new instance of Restore.



2804
2805
2806
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2804

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupString

Required. Immutable. A reference to the Backup used as the source from which this Restore will restore. Note that this Backup must be a sub-resource of the RestorePlan's backup_plan. Format: projects/*/locations/*/backupPlans/*/ backups/*. Corresponds to the JSON property backup

Returns:

  • (String)


2687
2688
2689
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2687

def backup
  @backup
end

#clusterString

Output only. The target cluster into which this Restore will restore data. Valid formats: - projects/*/locations/*/clusters/* - projects/*/zones/*/ clusters/* Inherited from parent RestorePlan's cluster value. Corresponds to the JSON property cluster

Returns:

  • (String)


2694
2695
2696
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2694

def cluster
  @cluster
end

#complete_timeString

Output only. Timestamp of when the restore operation completed. Corresponds to the JSON property completeTime

Returns:

  • (String)


2699
2700
2701
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2699

def complete_time
  @complete_time
end

#create_timeString

Output only. The timestamp when this Restore resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2704
2705
2706
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2704

def create_time
  @create_time
end

#descriptionString

Optional. User specified descriptive string for this Restore. Corresponds to the JSON property description

Returns:

  • (String)


2709
2710
2711
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2709

def description
  @description
end

#etagString

Output only. etag is used for optimistic concurrency control as a way to help prevent simultaneous updates of a restore from overwriting each other. It is strongly suggested that systems make use of the etag in the read-modify- write cycle to perform restore updates in order to avoid race conditions: An etag is returned in the response to GetRestore, and systems are expected to put that etag in the request to UpdateRestore or DeleteRestore to ensure that their change will be applied to the same version of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


2720
2721
2722
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2720

def etag
  @etag
end

#filterGoogle::Apis::GkebackupV1::Filter

Defines the filter for Restore. This filter can be used to further refine the resource selection of the Restore beyond the coarse-grained scope defined in the RestorePlan. exclusion_filters take precedence over inclusion_filters. If a resource matches both inclusion_filters and exclusion_filters, it will not be restored. Corresponds to the JSON property filter



2729
2730
2731
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2729

def filter
  @filter
end

#labelsHash<String,String>

A set of custom labels supplied by user. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2734
2735
2736
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2734

def labels
  @labels
end

#nameString

Output only. Identifier. The full name of the Restore resource. Format: projects/*/locations/*/restorePlans/*/restores/* Corresponds to the JSON property name

Returns:

  • (String)


2740
2741
2742
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2740

def name
  @name
end

#resources_excluded_countFixnum

Output only. Number of resources excluded during the restore execution. Corresponds to the JSON property resourcesExcludedCount

Returns:

  • (Fixnum)


2745
2746
2747
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2745

def resources_excluded_count
  @resources_excluded_count
end

#resources_failed_countFixnum

Output only. Number of resources that failed to be restored during the restore execution. Corresponds to the JSON property resourcesFailedCount

Returns:

  • (Fixnum)


2751
2752
2753
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2751

def resources_failed_count
  @resources_failed_count
end

#resources_restored_countFixnum

Output only. Number of resources restored during the restore execution. Corresponds to the JSON property resourcesRestoredCount

Returns:

  • (Fixnum)


2756
2757
2758
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2756

def resources_restored_count
  @resources_restored_count
end

#restore_configGoogle::Apis::GkebackupV1::RestoreConfig

Configuration of a restore. Corresponds to the JSON property restoreConfig



2761
2762
2763
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2761

def restore_config
  @restore_config
end

#stateString

Output only. The current state of the Restore. Corresponds to the JSON property state

Returns:

  • (String)


2766
2767
2768
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2766

def state
  @state
end

#state_reasonString

Output only. Human-readable description of why the Restore is in its current state. This field is only meant for human readability and should not be used programmatically as this field is not guaranteed to be consistent. Corresponds to the JSON property stateReason

Returns:

  • (String)


2773
2774
2775
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2773

def state_reason
  @state_reason
end

#troubleshooting_infoGoogle::Apis::GkebackupV1::TroubleshootingInfo

Stores information about troubleshooting doc for debugging a particular state of an operation (eg - backup/restore). This will be used by the end user to debug their operation failure scenario easily. Corresponds to the JSON property troubleshootingInfo



2780
2781
2782
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2780

def troubleshooting_info
  @troubleshooting_info
end

#uidString

Output only. Server generated global unique identifier of UUID format. Corresponds to the JSON property uid

Returns:

  • (String)


2786
2787
2788
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2786

def uid
  @uid
end

#update_timeString

Output only. The timestamp when this Restore resource was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2791
2792
2793
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2791

def update_time
  @update_time
end

#volume_data_restore_policy_overridesArray<Google::Apis::GkebackupV1::VolumeDataRestorePolicyOverride>

Optional. Immutable. Overrides the volume data restore policies selected in the Restore Config for override-scoped resources. Corresponds to the JSON property volumeDataRestorePolicyOverrides



2797
2798
2799
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2797

def volume_data_restore_policy_overrides
  @volume_data_restore_policy_overrides
end

#volumes_restored_countFixnum

Output only. Number of volumes restored during the restore execution. Corresponds to the JSON property volumesRestoredCount

Returns:

  • (Fixnum)


2802
2803
2804
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2802

def volumes_restored_count
  @volumes_restored_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2809

def update!(**args)
  @backup = args[:backup] if args.key?(:backup)
  @cluster = args[:cluster] if args.key?(:cluster)
  @complete_time = args[:complete_time] if args.key?(:complete_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @filter = args[:filter] if args.key?(:filter)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @resources_excluded_count = args[:resources_excluded_count] if args.key?(:resources_excluded_count)
  @resources_failed_count = args[:resources_failed_count] if args.key?(:resources_failed_count)
  @resources_restored_count = args[:resources_restored_count] if args.key?(:resources_restored_count)
  @restore_config = args[:restore_config] if args.key?(:restore_config)
  @state = args[:state] if args.key?(:state)
  @state_reason = args[:state_reason] if args.key?(:state_reason)
  @troubleshooting_info = args[:troubleshooting_info] if args.key?(:troubleshooting_info)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @volume_data_restore_policy_overrides = args[:volume_data_restore_policy_overrides] if args.key?(:volume_data_restore_policy_overrides)
  @volumes_restored_count = args[:volumes_restored_count] if args.key?(:volumes_restored_count)
end