Class: Google::Apis::GkebackupV1::RestoreOrder
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::RestoreOrder
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
Allows customers to specify dependencies between resources that Backup for GKE can use to compute a resasonable restore order.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ RestoreOrder
constructor
A new instance of RestoreOrder.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RestoreOrder
Returns a new instance of RestoreOrder.
2640 2641 2642 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2640 def initialize(**args) update!(**args) end |
Instance Attribute Details
#group_kind_dependencies ⇒ Array<Google::Apis::GkebackupV1::GroupKindDependency>
Optional. Contains a list of group kind dependency pairs provided by the
customer, that is used by Backup for GKE to generate a group kind restore
order.
Corresponds to the JSON property groupKindDependencies
2638 2639 2640 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2638 def group_kind_dependencies @group_kind_dependencies end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2645 2646 2647 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2645 def update!(**args) @group_kind_dependencies = args[:group_kind_dependencies] if args.key?(:group_kind_dependencies) end |