Class: Google::Apis::GkebackupV1::RestorePlanBinding
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::RestorePlanBinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
A RestorePlanBinding binds a RestorePlan with a RestoreChannel. This resource is created automatically when a RestorePlan is created using a RestoreChannel. This also serves as a holder for cross-project fields that need to be displayed in the current project.
Instance Attribute Summary collapse
-
#backup_plan ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#restore_plan ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RestorePlanBinding
constructor
A new instance of RestorePlanBinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RestorePlanBinding
Returns a new instance of RestorePlanBinding.
3223 3224 3225 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3223 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_plan ⇒ String
Output only. The fully qualified name of the BackupPlan bound to the specified
RestorePlan. projects/*/locations/*/backukpPlans/backup_plan`
Corresponds to the JSON propertybackupPlan`
3181 3182 3183 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3181 def backup_plan @backup_plan end |
#create_time ⇒ String
Output only. The timestamp when this binding was created.
Corresponds to the JSON property createTime
3186 3187 3188 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3186 def create_time @create_time end |
#etag ⇒ String
Output only. etag is used for optimistic concurrency control as a way to
help prevent simultaneous updates of a RestorePlanBinding from overwriting
each other. It is strongly suggested that systems make use of the 'etag' in
the read-modify-write cycle to perform RestorePlanBinding updates in order to
avoid race conditions: An etag is returned in the response to
GetRestorePlanBinding, and systems are expected to put that etag in the
request to UpdateRestorePlanBinding or DeleteRestorePlanBinding to ensure
that their change will be applied to the same version of the resource.
Corresponds to the JSON property etag
3198 3199 3200 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3198 def etag @etag end |
#name ⇒ String
Identifier. The fully qualified name of the RestorePlanBinding. projects/*/
locations/*/restoreChannels/*/restorePlanBindings/*
Corresponds to the JSON property name
3204 3205 3206 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3204 def name @name end |
#restore_plan ⇒ String
Output only. The fully qualified name of the RestorePlan bound to this
RestoreChannel. projects/*/locations/*/restorePlans/restore_plan`
Corresponds to the JSON propertyrestorePlan`
3210 3211 3212 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3210 def restore_plan @restore_plan end |
#uid ⇒ String
Output only. Server generated global unique identifier of UUID4
Corresponds to the JSON property uid
3216 3217 3218 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3216 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when this binding was created.
Corresponds to the JSON property updateTime
3221 3222 3223 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3221 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3228 3229 3230 3231 3232 3233 3234 3235 3236 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3228 def update!(**args) @backup_plan = args[:backup_plan] if args.key?(:backup_plan) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @restore_plan = args[:restore_plan] if args.key?(:restore_plan) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |