Class: Google::Apis::GkebackupV1::Schedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Defines scheduling parameters for automatically creating Backups via this BackupPlan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Schedule

Returns a new instance of Schedule.



3373
3374
3375
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3373

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cron_scheduleString

Optional. A standard cron string that defines a repeating schedule for creating Backups via this BackupPlan. This is mutually exclusive with the rpo_config field since at most one schedule can be defined for a BackupPlan. If this is defined, then backup_retain_days must also be defined. Default (empty): no automatic backup creation will occur. Corresponds to the JSON property cronSchedule

Returns:

  • (String)


3352
3353
3354
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3352

def cron_schedule
  @cron_schedule
end

#next_scheduled_backup_timeString

Output only. Start time of next scheduled backup under this BackupPlan by either cron_schedule or rpo config. Corresponds to the JSON property nextScheduledBackupTime

Returns:

  • (String)


3358
3359
3360
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3358

def next_scheduled_backup_time
  @next_scheduled_backup_time
end

#pausedBoolean Also known as: paused?

Optional. This flag denotes whether automatic Backup creation is paused for this BackupPlan. Default: False Corresponds to the JSON property paused

Returns:

  • (Boolean)


3364
3365
3366
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3364

def paused
  @paused
end

#rpo_configGoogle::Apis::GkebackupV1::RpoConfig

Defines RPO scheduling configuration for automatically creating Backups via this BackupPlan. Corresponds to the JSON property rpoConfig



3371
3372
3373
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3371

def rpo_config
  @rpo_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3378
3379
3380
3381
3382
3383
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3378

def update!(**args)
  @cron_schedule = args[:cron_schedule] if args.key?(:cron_schedule)
  @next_scheduled_backup_time = args[:next_scheduled_backup_time] if args.key?(:next_scheduled_backup_time)
  @paused = args[:paused] if args.key?(:paused)
  @rpo_config = args[:rpo_config] if args.key?(:rpo_config)
end