Class: Google::Apis::GkebackupV1::SubstitutionRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

A transformation rule to be applied against Kubernetes resources as they are selected for restoration from a Backup. A rule contains both filtering logic ( which resources are subject to substitution) and substitution logic.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubstitutionRule

Returns a new instance of SubstitutionRule.



3102
3103
3104
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3102

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#new_valueString

Optional. This is the new value to set for any fields that pass the filtering and selection criteria. To remove a value from a Kubernetes resource, either leave this field unspecified, or set it to the empty string (""). Corresponds to the JSON property newValue

Returns:

  • (String)


3060
3061
3062
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3060

def new_value
  @new_value
end

#original_value_patternString

Optional. (Filtering parameter) This is a regular expression that is compared against the fields matched by the target_json_path expression (and must also have passed the previous filters). Substitution will not be performed against fields whose value does not match this expression. If this field is NOT specified, then ALL fields matched by the target_json_path expression will undergo substitution. Note that an empty (e.g., "", rather than unspecified) value for this field will only match empty fields. Corresponds to the JSON property originalValuePattern

Returns:

  • (String)


3072
3073
3074
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3072

def original_value_pattern
  @original_value_pattern
end

#target_group_kindsArray<Google::Apis::GkebackupV1::GroupKind>

Optional. (Filtering parameter) Any resource subject to substitution must belong to one of the listed "types". If this field is not provided, no type filtering will be performed (all resources of all types matching previous filtering parameters will be candidates for substitution). Corresponds to the JSON property targetGroupKinds



3080
3081
3082
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3080

def target_group_kinds
  @target_group_kinds
end

#target_json_pathString

Required. This is a JSONPath expression that matches specific fields of candidate resources and it operates as both a filtering parameter (resources that are not matched with this expression will not be candidates for substitution) as well as a field identifier (identifies exactly which fields out of the candidate resources will be modified). Corresponds to the JSON property targetJsonPath

Returns:

  • (String)


3090
3091
3092
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3090

def target_json_path
  @target_json_path
end

#target_namespacesArray<String>

Optional. (Filtering parameter) Any resource subject to substitution must be contained within one of the listed Kubernetes Namespace in the Backup. If this field is not provided, no namespace filtering will be performed (all resources in all Namespaces, including all cluster-scoped resources, will be candidates for substitution). To mix cluster-scoped and namespaced resources in the same rule, use an empty string ("") as one of the target namespaces. Corresponds to the JSON property targetNamespaces

Returns:

  • (Array<String>)


3100
3101
3102
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3100

def target_namespaces
  @target_namespaces
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3107
3108
3109
3110
3111
3112
3113
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3107

def update!(**args)
  @new_value = args[:new_value] if args.key?(:new_value)
  @original_value_pattern = args[:original_value_pattern] if args.key?(:original_value_pattern)
  @target_group_kinds = args[:target_group_kinds] if args.key?(:target_group_kinds)
  @target_json_path = args[:target_json_path] if args.key?(:target_json_path)
  @target_namespaces = args[:target_namespaces] if args.key?(:target_namespaces)
end