Class: Google::Apis::GkebackupV1::TransformationRule
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::TransformationRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
A transformation rule to be applied against Kubernetes resources as they are selected for restoration from a Backup. A rule contains both filtering logic ( which resources are subject to transform) and transformation logic.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#field_actions ⇒ Array<Google::Apis::GkebackupV1::TransformationRuleAction>
Required.
-
#resource_filter ⇒ Google::Apis::GkebackupV1::ResourceFilter
ResourceFilter specifies matching criteria to limit the scope of a change to a specific set of kubernetes resources that are selected for restoration from a backup.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TransformationRule
constructor
A new instance of TransformationRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TransformationRule
Returns a new instance of TransformationRule.
3711 3712 3713 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3711 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. The description is a user specified string description of the
transformation rule.
Corresponds to the JSON property description
3694 3695 3696 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3694 def description @description end |
#field_actions ⇒ Array<Google::Apis::GkebackupV1::TransformationRuleAction>
Required. A list of transformation rule actions to take against candidate
resources. Actions are executed in order defined - this order matters, as they
could potentially interfere with each other and the first operation could
affect the outcome of the second operation.
Corresponds to the JSON property fieldActions
3702 3703 3704 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3702 def field_actions @field_actions end |
#resource_filter ⇒ Google::Apis::GkebackupV1::ResourceFilter
ResourceFilter specifies matching criteria to limit the scope of a change to a
specific set of kubernetes resources that are selected for restoration from a
backup.
Corresponds to the JSON property resourceFilter
3709 3710 3711 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3709 def resource_filter @resource_filter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3716 3717 3718 3719 3720 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3716 def update!(**args) @description = args[:description] if args.key?(:description) @field_actions = args[:field_actions] if args.key?(:field_actions) @resource_filter = args[:resource_filter] if args.key?(:resource_filter) end |