Class: Google::Apis::GkebackupV1::VolumeRestore
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::VolumeRestore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
Represents the operation of restoring a volume from a VolumeBackup.
Instance Attribute Summary collapse
-
#complete_time ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#state_message ⇒ String
Output only.
-
#target_pvc ⇒ Google::Apis::GkebackupV1::NamespacedName
A reference to a namespaced resource in Kubernetes.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#volume_backup ⇒ String
Output only.
-
#volume_handle ⇒ String
Output only.
-
#volume_type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VolumeRestore
constructor
A new instance of VolumeRestore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VolumeRestore
Returns a new instance of VolumeRestore.
4028 4029 4030 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 4028 def initialize(**args) update!(**args) end |
Instance Attribute Details
#complete_time ⇒ String
Output only. The timestamp when the associated underlying volume restoration
completed.
Corresponds to the JSON property completeTime
3961 3962 3963 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3961 def complete_time @complete_time end |
#create_time ⇒ String
Output only. The timestamp when this VolumeRestore resource was created.
Corresponds to the JSON property createTime
3966 3967 3968 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3966 def create_time @create_time end |
#etag ⇒ String
Output only. etag is used for optimistic concurrency control as a way to
help prevent simultaneous updates of a volume restore from overwriting each
other. It is strongly suggested that systems make use of the etag in the
read-modify-write cycle to perform volume restore updates in order to avoid
race conditions.
Corresponds to the JSON property etag
3975 3976 3977 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3975 def etag @etag end |
#name ⇒ String
Output only. Full name of the VolumeRestore resource. Format: projects/*/
locations/*/restorePlans/*/restores/*/volumeRestores/*
Corresponds to the JSON property name
3981 3982 3983 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3981 def name @name end |
#state ⇒ String
Output only. The current state of this VolumeRestore.
Corresponds to the JSON property state
3986 3987 3988 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3986 def state @state end |
#state_message ⇒ String
Output only. A human readable message explaining why the VolumeRestore is in
its current state.
Corresponds to the JSON property stateMessage
3992 3993 3994 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3992 def @state_message end |
#target_pvc ⇒ Google::Apis::GkebackupV1::NamespacedName
A reference to a namespaced resource in Kubernetes.
Corresponds to the JSON property targetPvc
3997 3998 3999 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3997 def target_pvc @target_pvc end |
#uid ⇒ String
Output only. Server generated global unique identifier of UUID format.
Corresponds to the JSON property uid
4003 4004 4005 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 4003 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when this VolumeRestore resource was last updated.
Corresponds to the JSON property updateTime
4008 4009 4010 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 4008 def update_time @update_time end |
#volume_backup ⇒ String
Output only. The full name of the VolumeBackup from which the volume will be
restored. Format: projects/*/locations/*/backupPlans/*/backups/*/
volumeBackups/*.
Corresponds to the JSON property volumeBackup
4015 4016 4017 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 4015 def volume_backup @volume_backup end |
#volume_handle ⇒ String
Output only. A storage system-specific opaque handler to the underlying volume
created for the target PVC from the volume backup.
Corresponds to the JSON property volumeHandle
4021 4022 4023 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 4021 def volume_handle @volume_handle end |
#volume_type ⇒ String
Output only. The type of volume provisioned
Corresponds to the JSON property volumeType
4026 4027 4028 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 4026 def volume_type @volume_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4033 4034 4035 4036 4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 4033 def update!(**args) @complete_time = args[:complete_time] if args.key?(:complete_time) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @state_message = args[:state_message] if args.key?(:state_message) @target_pvc = args[:target_pvc] if args.key?(:target_pvc) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @volume_backup = args[:volume_backup] if args.key?(:volume_backup) @volume_handle = args[:volume_handle] if args.key?(:volume_handle) @volume_type = args[:volume_type] if args.key?(:volume_type) end |