Class: Google::Apis::GkebackupV1::BackupChannel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

A BackupChannel imposes constraints on where clusters can be backed up. The BackupChannel should be in the same project and region as the cluster being backed up. The backup can be created only in destination_project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupChannel

Returns a new instance of BackupChannel.



686
687
688
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 686

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when this BackupChannel resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


632
633
634
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 632

def create_time
  @create_time
end

#descriptionString

Optional. User specified descriptive string for this BackupChannel. Corresponds to the JSON property description

Returns:

  • (String)


637
638
639
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 637

def description
  @description
end

#destination_projectString

Required. Immutable. The project where Backups are allowed to be stored. The format is projects/projectIdor `projects/`projectNumber. Corresponds to the JSON property destinationProject

Returns:

  • (String)


643
644
645
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 643

def destination_project
  @destination_project
end

#destination_project_idString

Output only. The project_id where Backups are allowed to be stored. Example Project ID: "my-project-id". This will be an OUTPUT_ONLY field to return the project_id of the destination project. Corresponds to the JSON property destinationProjectId

Returns:

  • (String)


650
651
652
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 650

def destination_project_id
  @destination_project_id
end

#etagString

Output only. etag is used for optimistic concurrency control as a way to help prevent simultaneous updates of a BackupChannel from overwriting each other. It is strongly suggested that systems make use of the 'etag' in the read-modify-write cycle to perform BackupChannel updates in order to avoid race conditions: An etag is returned in the response to GetBackupChannel, and systems are expected to put that etag in the request to UpdateBackupChannel or DeleteBackupChannel to ensure that their change will be applied to the same version of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


662
663
664
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 662

def etag
  @etag
end

#labelsHash<String,String>

Optional. A set of custom labels supplied by user. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


667
668
669
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 667

def labels
  @labels
end

#nameString

Identifier. The fully qualified name of the BackupChannel. projects/*/ locations/*/backupChannels/* Corresponds to the JSON property name

Returns:

  • (String)


673
674
675
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 673

def name
  @name
end

#uidString

Output only. Server generated global unique identifier of UUID format. Corresponds to the JSON property uid

Returns:

  • (String)


679
680
681
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 679

def uid
  @uid
end

#update_timeString

Output only. The timestamp when this BackupChannel resource was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


684
685
686
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 684

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



691
692
693
694
695
696
697
698
699
700
701
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 691

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @destination_project = args[:destination_project] if args.key?(:destination_project)
  @destination_project_id = args[:destination_project_id] if args.key?(:destination_project_id)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end