Class: Google::Apis::GkebackupV1::BackupChannel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

A BackupChannel imposes constraints on where clusters can be backed up. The BackupChannel should be in the same project and region as the cluster being backed up. The backup can be created only in destination_project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupChannel

Returns a new instance of BackupChannel.



673
674
675
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 673

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when this BackupChannel resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


619
620
621
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 619

def create_time
  @create_time
end

#descriptionString

Optional. User specified descriptive string for this BackupChannel. Corresponds to the JSON property description

Returns:

  • (String)


624
625
626
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 624

def description
  @description
end

#destination_projectString

Required. Immutable. The project where Backups are allowed to be stored. The format is projects/projectIdor `projects/`projectNumber. Corresponds to the JSON property destinationProject

Returns:

  • (String)


630
631
632
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 630

def destination_project
  @destination_project
end

#destination_project_idString

Output only. The project_id where Backups are allowed to be stored. Example Project ID: "my-project-id". This will be an OUTPUT_ONLY field to return the project_id of the destination project. Corresponds to the JSON property destinationProjectId

Returns:

  • (String)


637
638
639
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 637

def destination_project_id
  @destination_project_id
end

#etagString

Output only. etag is used for optimistic concurrency control as a way to help prevent simultaneous updates of a BackupChannel from overwriting each other. It is strongly suggested that systems make use of the 'etag' in the read-modify-write cycle to perform BackupChannel updates in order to avoid race conditions: An etag is returned in the response to GetBackupChannel, and systems are expected to put that etag in the request to UpdateBackupChannel or DeleteBackupChannel to ensure that their change will be applied to the same version of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


649
650
651
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 649

def etag
  @etag
end

#labelsHash<String,String>

Optional. A set of custom labels supplied by user. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


654
655
656
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 654

def labels
  @labels
end

#nameString

Identifier. The fully qualified name of the BackupChannel. projects/*/ locations/*/backupChannels/* Corresponds to the JSON property name

Returns:

  • (String)


660
661
662
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 660

def name
  @name
end

#uidString

Output only. Server generated global unique identifier of UUID format. Corresponds to the JSON property uid

Returns:

  • (String)


666
667
668
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 666

def uid
  @uid
end

#update_timeString

Output only. The timestamp when this BackupChannel resource was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


671
672
673
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 671

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



678
679
680
681
682
683
684
685
686
687
688
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 678

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @destination_project = args[:destination_project] if args.key?(:destination_project)
  @destination_project_id = args[:destination_project_id] if args.key?(:destination_project_id)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end