Class: Google::Apis::GkebackupV1::BackupConfigDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

BackupConfigDetails defines the configuration of Backups created via this BackupPlan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupConfigDetails

Returns a new instance of BackupConfigDetails.



534
535
536
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 534

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_namespacesBoolean Also known as: all_namespaces?

Output only. If True, include all namespaced resources Corresponds to the JSON property allNamespaces

Returns:

  • (Boolean)


501
502
503
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 501

def all_namespaces
  @all_namespaces
end

#encryption_keyGoogle::Apis::GkebackupV1::EncryptionKey

Defined a customer managed encryption key that will be used to encrypt Backup artifacts. Corresponds to the JSON property encryptionKey



508
509
510
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 508

def encryption_key
  @encryption_key
end

#include_secretsBoolean Also known as: include_secrets?

Output only. This flag specifies whether Kubernetes Secret resources should be included when they fall into the scope of Backups. Default: False Corresponds to the JSON property includeSecrets

Returns:

  • (Boolean)


514
515
516
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 514

def include_secrets
  @include_secrets
end

#include_volume_dataBoolean Also known as: include_volume_data?

Output only. This flag specifies whether volume data should be backed up when PVCs are included in the scope of a Backup. Default: False Corresponds to the JSON property includeVolumeData

Returns:

  • (Boolean)


521
522
523
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 521

def include_volume_data
  @include_volume_data
end

#selected_applicationsGoogle::Apis::GkebackupV1::NamespacedNames

A list of namespaced Kubernetes resources. Corresponds to the JSON property selectedApplications



527
528
529
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 527

def selected_applications
  @selected_applications
end

#selected_namespacesGoogle::Apis::GkebackupV1::Namespaces

A list of Kubernetes Namespaces. Corresponds to the JSON property selectedNamespaces



532
533
534
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 532

def selected_namespaces
  @selected_namespaces
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



539
540
541
542
543
544
545
546
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 539

def update!(**args)
  @all_namespaces = args[:all_namespaces] if args.key?(:all_namespaces)
  @encryption_key = args[:encryption_key] if args.key?(:encryption_key)
  @include_secrets = args[:include_secrets] if args.key?(:include_secrets)
  @include_volume_data = args[:include_volume_data] if args.key?(:include_volume_data)
  @selected_applications = args[:selected_applications] if args.key?(:selected_applications)
  @selected_namespaces = args[:selected_namespaces] if args.key?(:selected_namespaces)
end