Class: Google::Apis::GkebackupV1::BackupPlanBinding
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::BackupPlanBinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
A BackupPlanBinding binds a BackupPlan with a BackupChannel. This resource is created automatically when a BackupPlan is created using a BackupChannel. This also serves as a holder for cross-project fields that need to be displayed in the current project.
Instance Attribute Summary collapse
-
#backup_plan ⇒ String
Output only.
-
#backup_plan_details ⇒ Google::Apis::GkebackupV1::BackupPlanDetails
Contains metadata about the backup plan/backup.
-
#cluster ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupPlanBinding
constructor
A new instance of BackupPlanBinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupPlanBinding
Returns a new instance of BackupPlanBinding.
1032 1033 1034 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1032 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_plan ⇒ String
Output only. Immutable. The fully qualified name of the BackupPlan bound with
the parent BackupChannel. projects/*/locations/*/backupPlans/backup_plan`
Corresponds to the JSON propertybackupPlan`
984 985 986 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 984 def backup_plan @backup_plan end |
#backup_plan_details ⇒ Google::Apis::GkebackupV1::BackupPlanDetails
Contains metadata about the backup plan/backup.
Corresponds to the JSON property backupPlanDetails
989 990 991 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 989 def backup_plan_details @backup_plan_details end |
#cluster ⇒ String
Output only. Immutable. The fully qualified name of the cluster that is being
backed up Valid formats: - projects/*/locations/*/clusters/* - projects/*/
zones/*/clusters/*
Corresponds to the JSON property cluster
996 997 998 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 996 def cluster @cluster end |
#create_time ⇒ String
Output only. The timestamp when this binding was created.
Corresponds to the JSON property createTime
1001 1002 1003 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1001 def create_time @create_time end |
#etag ⇒ String
Output only. etag is used for optimistic concurrency control as a way to
help prevent simultaneous updates of a BackupPlanBinding from overwriting each
other. It is strongly suggested that systems make use of the 'etag' in the
read-modify-write cycle to perform BackupPlanBinding updates in order to avoid
race conditions: An etag is returned in the response to
GetBackupPlanBinding, and systems are expected to put that etag in the
request to UpdateBackupPlanBinding or DeleteBackupPlanBinding to ensure
that their change will be applied to the same version of the resource.
Corresponds to the JSON property etag
1013 1014 1015 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1013 def etag @etag end |
#name ⇒ String
Identifier. The fully qualified name of the BackupPlanBinding. projects/*/
locations/*/backupChannels/*/backupPlanBindings/*
Corresponds to the JSON property name
1019 1020 1021 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1019 def name @name end |
#uid ⇒ String
Output only. Server generated global unique identifier of UUID4
Corresponds to the JSON property uid
1025 1026 1027 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1025 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when this binding was created.
Corresponds to the JSON property updateTime
1030 1031 1032 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1030 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1037 def update!(**args) @backup_plan = args[:backup_plan] if args.key?(:backup_plan) @backup_plan_details = args[:backup_plan_details] if args.key?(:backup_plan_details) @cluster = args[:cluster] if args.key?(:cluster) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |