Class: Google::Apis::GkebackupV1::BackupPlanBinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

A BackupPlanBinding binds a BackupPlan with a BackupChannel. This resource is created automatically when a BackupPlan is created using a BackupChannel. This also serves as a holder for cross-project fields that need to be displayed in the current project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupPlanBinding

Returns a new instance of BackupPlanBinding.



764
765
766
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 764

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_planString

Output only. Immutable. The fully qualified name of the BackupPlan bound with the parent BackupChannel. projects/*/locations/*/backupPlans/backup_plan` Corresponds to the JSON propertybackupPlan`

Returns:

  • (String)


716
717
718
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 716

def backup_plan
  @backup_plan
end

#backup_plan_detailsGoogle::Apis::GkebackupV1::BackupPlanDetails

Contains metadata about the backup plan/backup. Corresponds to the JSON property backupPlanDetails



721
722
723
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 721

def backup_plan_details
  @backup_plan_details
end

#clusterString

Output only. Immutable. The fully qualified name of the cluster that is being backed up Valid formats: - projects/*/locations/*/clusters/* - projects/*/ zones/*/clusters/* Corresponds to the JSON property cluster

Returns:

  • (String)


728
729
730
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 728

def cluster
  @cluster
end

#create_timeString

Output only. The timestamp when this binding was created. Corresponds to the JSON property createTime

Returns:

  • (String)


733
734
735
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 733

def create_time
  @create_time
end

#etagString

Output only. etag is used for optimistic concurrency control as a way to help prevent simultaneous updates of a BackupPlanBinding from overwriting each other. It is strongly suggested that systems make use of the 'etag' in the read-modify-write cycle to perform BackupPlanBinding updates in order to avoid race conditions: An etag is returned in the response to GetBackupPlanBinding, and systems are expected to put that etag in the request to UpdateBackupPlanBinding or DeleteBackupPlanBinding to ensure that their change will be applied to the same version of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


745
746
747
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 745

def etag
  @etag
end

#nameString

Identifier. The fully qualified name of the BackupPlanBinding. projects/*/ locations/*/backupChannels/*/backupPlanBindings/* Corresponds to the JSON property name

Returns:

  • (String)


751
752
753
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 751

def name
  @name
end

#uidString

Output only. Server generated global unique identifier of UUID4 Corresponds to the JSON property uid

Returns:

  • (String)


757
758
759
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 757

def uid
  @uid
end

#update_timeString

Output only. The timestamp when this binding was created. Corresponds to the JSON property updateTime

Returns:

  • (String)


762
763
764
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 762

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



769
770
771
772
773
774
775
776
777
778
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 769

def update!(**args)
  @backup_plan = args[:backup_plan] if args.key?(:backup_plan)
  @backup_plan_details = args[:backup_plan_details] if args.key?(:backup_plan_details)
  @cluster = args[:cluster] if args.key?(:cluster)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end