Class: Google::Apis::GkebackupV1::BackupPlanDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Contains metadata about the backup plan/backup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupPlanDetails

Returns a new instance of BackupPlanDetails.



1099
1100
1101
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1099

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_config_detailsGoogle::Apis::GkebackupV1::BackupConfigDetails

BackupConfigDetails defines the configuration of Backups created via this BackupPlan. Corresponds to the JSON property backupConfigDetails



1057
1058
1059
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1057

def backup_config_details
  @backup_config_details
end

#last_successful_backupString

Output only. The fully qualified name of the last successful Backup created under this BackupPlan. projects/*/locations/*/backupPlans/*/backups/* Corresponds to the JSON property lastSuccessfulBackup

Returns:

  • (String)


1063
1064
1065
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1063

def last_successful_backup
  @last_successful_backup
end

#last_successful_backup_timeString

Output only. Completion time of the last successful Backup. This is sourced from a successful Backup's complete_time field. Corresponds to the JSON property lastSuccessfulBackupTime

Returns:

  • (String)


1069
1070
1071
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1069

def last_successful_backup_time
  @last_successful_backup_time
end

#next_scheduled_backup_timeString

Output only. Start time of next scheduled backup under this BackupPlan by either cron_schedule or rpo config. This is sourced from BackupPlan. Corresponds to the JSON property nextScheduledBackupTime

Returns:

  • (String)


1075
1076
1077
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1075

def next_scheduled_backup_time
  @next_scheduled_backup_time
end

#protected_pod_countFixnum

Output only. The number of Kubernetes Pods backed up in the last successful Backup created via this BackupPlan. Corresponds to the JSON property protectedPodCount

Returns:

  • (Fixnum)


1081
1082
1083
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1081

def protected_pod_count
  @protected_pod_count
end

#retention_policy_detailsGoogle::Apis::GkebackupV1::RetentionPolicyDetails

RetentionPolicyDetails defines a Backup retention policy for a BackupPlan. Corresponds to the JSON property retentionPolicyDetails



1086
1087
1088
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1086

def retention_policy_details
  @retention_policy_details
end

#rpo_risk_levelFixnum

Output only. A number that represents the current risk level of this BackupPlan from RPO perspective with 1 being no risk and 5 being highest risk. Corresponds to the JSON property rpoRiskLevel

Returns:

  • (Fixnum)


1092
1093
1094
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1092

def rpo_risk_level
  @rpo_risk_level
end

#stateString

Output only. State of the BackupPlan. Corresponds to the JSON property state

Returns:

  • (String)


1097
1098
1099
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1097

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1104

def update!(**args)
  @backup_config_details = args[:backup_config_details] if args.key?(:backup_config_details)
  @last_successful_backup = args[:last_successful_backup] if args.key?(:last_successful_backup)
  @last_successful_backup_time = args[:last_successful_backup_time] if args.key?(:last_successful_backup_time)
  @next_scheduled_backup_time = args[:next_scheduled_backup_time] if args.key?(:next_scheduled_backup_time)
  @protected_pod_count = args[:protected_pod_count] if args.key?(:protected_pod_count)
  @retention_policy_details = args[:retention_policy_details] if args.key?(:retention_policy_details)
  @rpo_risk_level = args[:rpo_risk_level] if args.key?(:rpo_risk_level)
  @state = args[:state] if args.key?(:state)
end