Class: Google::Apis::GkebackupV1::BackupPlanDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Contains metadata about the backup plan/backup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupPlanDetails

Returns a new instance of BackupPlanDetails.



831
832
833
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 831

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_config_detailsGoogle::Apis::GkebackupV1::BackupConfigDetails

BackupConfigDetails defines the configuration of Backups created via this BackupPlan. Corresponds to the JSON property backupConfigDetails



789
790
791
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 789

def backup_config_details
  @backup_config_details
end

#last_successful_backupString

Output only. The fully qualified name of the last successful Backup created under this BackupPlan. projects/*/locations/*/backupPlans/*/backups/* Corresponds to the JSON property lastSuccessfulBackup

Returns:

  • (String)


795
796
797
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 795

def last_successful_backup
  @last_successful_backup
end

#last_successful_backup_timeString

Output only. Completion time of the last successful Backup. This is sourced from a successful Backup's complete_time field. Corresponds to the JSON property lastSuccessfulBackupTime

Returns:

  • (String)


801
802
803
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 801

def last_successful_backup_time
  @last_successful_backup_time
end

#next_scheduled_backup_timeString

Output only. Start time of next scheduled backup under this BackupPlan by either cron_schedule or rpo config. This is sourced from BackupPlan. Corresponds to the JSON property nextScheduledBackupTime

Returns:

  • (String)


807
808
809
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 807

def next_scheduled_backup_time
  @next_scheduled_backup_time
end

#protected_pod_countFixnum

Output only. The number of Kubernetes Pods backed up in the last successful Backup created via this BackupPlan. Corresponds to the JSON property protectedPodCount

Returns:

  • (Fixnum)


813
814
815
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 813

def protected_pod_count
  @protected_pod_count
end

#retention_policy_detailsGoogle::Apis::GkebackupV1::RetentionPolicyDetails

RetentionPolicyDetails defines a Backup retention policy for a BackupPlan. Corresponds to the JSON property retentionPolicyDetails



818
819
820
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 818

def retention_policy_details
  @retention_policy_details
end

#rpo_risk_levelFixnum

Output only. A number that represents the current risk level of this BackupPlan from RPO perspective with 1 being no risk and 5 being highest risk. Corresponds to the JSON property rpoRiskLevel

Returns:

  • (Fixnum)


824
825
826
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 824

def rpo_risk_level
  @rpo_risk_level
end

#stateString

Output only. State of the BackupPlan. Corresponds to the JSON property state

Returns:

  • (String)


829
830
831
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 829

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



836
837
838
839
840
841
842
843
844
845
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 836

def update!(**args)
  @backup_config_details = args[:backup_config_details] if args.key?(:backup_config_details)
  @last_successful_backup = args[:last_successful_backup] if args.key?(:last_successful_backup)
  @last_successful_backup_time = args[:last_successful_backup_time] if args.key?(:last_successful_backup_time)
  @next_scheduled_backup_time = args[:next_scheduled_backup_time] if args.key?(:next_scheduled_backup_time)
  @protected_pod_count = args[:protected_pod_count] if args.key?(:protected_pod_count)
  @retention_policy_details = args[:retention_policy_details] if args.key?(:retention_policy_details)
  @rpo_risk_level = args[:rpo_risk_level] if args.key?(:rpo_risk_level)
  @state = args[:state] if args.key?(:state)
end