Class: Google::Apis::GkebackupV1::BdrBackupPlanJobLog
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::BdrBackupPlanJobLog
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
Log entry for BDRBackupPlanJobLog for resources using BackupPlan based protection.
Instance Attribute Summary collapse
-
#backup_plan_name ⇒ String
Canonical resource name for Backup Plan Plan of the job.
-
#end_time ⇒ String
End time of the job.
-
#error_code ⇒ Fixnum
The error code.
-
#error_message ⇒ String
The user readable error message.
-
#error_type ⇒ String
The name of the error type eg.
-
#job_category ⇒ String
The category field displays the category of the job.
-
#job_id ⇒ String
The job_id field displays the identifier of the job being reported.
-
#job_status ⇒ String
The status field displays the status of the job.
-
#new_backup_plan_revision_id ⇒ String
User friendly revision id e.g.
-
#new_backup_plan_revision_name ⇒ String
Full resource name for new backup plan revision Corresponds to the JSON property
newBackupPlanRevisionName. -
#previous_backup_plan_revision_id ⇒ String
User friendly revision id e.g.
-
#previous_backup_plan_revision_name ⇒ String
Full resource name for previous backup plan revision Corresponds to the JSON property
previousBackupPlanRevisionName. -
#previous_backup_rules ⇒ Array<Google::Apis::GkebackupV1::BackupRuleDetail>
Previous Backup Plan rules.
-
#resource_type ⇒ String
The resource_type field displays the type of the protected resource.
-
#revised_backup_rules ⇒ Array<Google::Apis::GkebackupV1::BackupRuleDetail>
Revised Backup Plan rules.
-
#start_time ⇒ String
Start time of the job.
-
#workloads_affected_count ⇒ Fixnum
The total number of workloads affected by the job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BdrBackupPlanJobLog
constructor
A new instance of BdrBackupPlanJobLog.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BdrBackupPlanJobLog
Returns a new instance of BdrBackupPlanJobLog.
189 190 191 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 189 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_plan_name ⇒ String
Canonical resource name for Backup Plan Plan of the job.
Corresponds to the JSON property backupPlanName
104 105 106 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 104 def backup_plan_name @backup_plan_name end |
#end_time ⇒ String
End time of the job.
Corresponds to the JSON property endTime
109 110 111 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 109 def end_time @end_time end |
#error_code ⇒ Fixnum
The error code. Only populated in error scenarios.
Corresponds to the JSON property errorCode
114 115 116 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 114 def error_code @error_code end |
#error_message ⇒ String
The user readable error message. Only populated in error scenarios.
Corresponds to the JSON property errorMessage
119 120 121 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 119 def @error_message end |
#error_type ⇒ String
The name of the error type eg. PERMISSION_DENIED. Only populated in error
scenarios.
Corresponds to the JSON property errorType
125 126 127 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 125 def error_type @error_type end |
#job_category ⇒ String
The category field displays the category of the job. Can be one of [
UPDATE_BACKUP_PLAN].
Corresponds to the JSON property jobCategory
131 132 133 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 131 def job_category @job_category end |
#job_id ⇒ String
The job_id field displays the identifier of the job being reported.
Corresponds to the JSON property jobId
136 137 138 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 136 def job_id @job_id end |
#job_status ⇒ String
The status field displays the status of the job. Can be one of [RUNNING,
SUCCESSFUL, FAILED].
Corresponds to the JSON property jobStatus
142 143 144 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 142 def job_status @job_status end |
#new_backup_plan_revision_id ⇒ String
User friendly revision id e.g. v0, v1 etc.
Corresponds to the JSON property newBackupPlanRevisionId
147 148 149 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 147 def new_backup_plan_revision_id @new_backup_plan_revision_id end |
#new_backup_plan_revision_name ⇒ String
Full resource name for new backup plan revision
Corresponds to the JSON property newBackupPlanRevisionName
152 153 154 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 152 def new_backup_plan_revision_name @new_backup_plan_revision_name end |
#previous_backup_plan_revision_id ⇒ String
User friendly revision id e.g. v0, v1 etc.
Corresponds to the JSON property previousBackupPlanRevisionId
157 158 159 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 157 def previous_backup_plan_revision_id @previous_backup_plan_revision_id end |
#previous_backup_plan_revision_name ⇒ String
Full resource name for previous backup plan revision
Corresponds to the JSON property previousBackupPlanRevisionName
162 163 164 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 162 def previous_backup_plan_revision_name @previous_backup_plan_revision_name end |
#previous_backup_rules ⇒ Array<Google::Apis::GkebackupV1::BackupRuleDetail>
Previous Backup Plan rules.
Corresponds to the JSON property previousBackupRules
167 168 169 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 167 def previous_backup_rules @previous_backup_rules end |
#resource_type ⇒ String
The resource_type field displays the type of the protected resource.
Corresponds to the JSON property resourceType
172 173 174 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 172 def resource_type @resource_type end |
#revised_backup_rules ⇒ Array<Google::Apis::GkebackupV1::BackupRuleDetail>
Revised Backup Plan rules.
Corresponds to the JSON property revisedBackupRules
177 178 179 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 177 def revised_backup_rules @revised_backup_rules end |
#start_time ⇒ String
Start time of the job.
Corresponds to the JSON property startTime
182 183 184 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 182 def start_time @start_time end |
#workloads_affected_count ⇒ Fixnum
The total number of workloads affected by the job.
Corresponds to the JSON property workloadsAffectedCount
187 188 189 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 187 def workloads_affected_count @workloads_affected_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 194 def update!(**args) @backup_plan_name = args[:backup_plan_name] if args.key?(:backup_plan_name) @end_time = args[:end_time] if args.key?(:end_time) @error_code = args[:error_code] if args.key?(:error_code) @error_message = args[:error_message] if args.key?(:error_message) @error_type = args[:error_type] if args.key?(:error_type) @job_category = args[:job_category] if args.key?(:job_category) @job_id = args[:job_id] if args.key?(:job_id) @job_status = args[:job_status] if args.key?(:job_status) @new_backup_plan_revision_id = args[:new_backup_plan_revision_id] if args.key?(:new_backup_plan_revision_id) @new_backup_plan_revision_name = args[:new_backup_plan_revision_name] if args.key?(:new_backup_plan_revision_name) @previous_backup_plan_revision_id = args[:previous_backup_plan_revision_id] if args.key?(:previous_backup_plan_revision_id) @previous_backup_plan_revision_name = args[:previous_backup_plan_revision_name] if args.key?(:previous_backup_plan_revision_name) @previous_backup_rules = args[:previous_backup_rules] if args.key?(:previous_backup_rules) @resource_type = args[:resource_type] if args.key?(:resource_type) @revised_backup_rules = args[:revised_backup_rules] if args.key?(:revised_backup_rules) @start_time = args[:start_time] if args.key?(:start_time) @workloads_affected_count = args[:workloads_affected_count] if args.key?(:workloads_affected_count) end |