Class: Google::Apis::GkebackupV1::BdrBackupRestoreJobLog

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Log entry for Backup and Restore Job for resources using BackupPlan based protection. Next Id: 23

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BdrBackupRestoreJobLog

Returns a new instance of BdrBackupRestoreJobLog.



333
334
335
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 333

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_consistency_timeString

Backup consistency time. Corresponds to the JSON property backupConsistencyTime

Returns:

  • (String)


223
224
225
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 223

def backup_consistency_time
  @backup_consistency_time
end

#backup_nameString

Full resource name of the backup created in backup jobs and used in restore jobs. Corresponds to the JSON property backupName

Returns:

  • (String)


229
230
231
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 229

def backup_name
  @backup_name
end

#backup_plan_nameString

Full resource name for Backup Plan of the job. Only populated for Scheduled Backup and Adhoc Backup. Corresponds to the JSON property backupPlanName

Returns:

  • (String)


235
236
237
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 235

def backup_plan_name
  @backup_plan_name
end

#backup_retention_daysFixnum

Backup retention in days. Corresponds to the JSON property backupRetentionDays

Returns:

  • (Fixnum)


240
241
242
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 240

def backup_retention_days
  @backup_retention_days
end

#backup_ruleString

Name of the backup rule. Only populated for Scheduled Backup and Adhoc Backup. Corresponds to the JSON property backupRule

Returns:

  • (String)


245
246
247
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 245

def backup_rule
  @backup_rule
end

#backup_vault_nameString

Full resource name backup vault name Corresponds to the JSON property backupVaultName

Returns:

  • (String)


250
251
252
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 250

def backup_vault_name
  @backup_vault_name
end

#end_timeString

End time of the job. Corresponds to the JSON property endTime

Returns:

  • (String)


255
256
257
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 255

def end_time
  @end_time
end

#error_codeFixnum

The error code. Only populated in error scenarios. Corresponds to the JSON property errorCode

Returns:

  • (Fixnum)


260
261
262
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 260

def error_code
  @error_code
end

#error_messageString

The user readable error message. Only populated in error scenarios. Corresponds to the JSON property errorMessage

Returns:

  • (String)


265
266
267
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 265

def error_message
  @error_message
end

#error_typeString

The name of the error type eg. PERMISSION_DENIED. Only populated in error scenarios. Corresponds to the JSON property errorType

Returns:

  • (String)


271
272
273
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 271

def error_type
  @error_type
end

#incremental_backup_size_gibFloat

The amount of incremental backup data copied. Corresponds to the JSON property incrementalBackupSizeGib

Returns:

  • (Float)


276
277
278
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 276

def incremental_backup_size_gib
  @incremental_backup_size_gib
end

#job_categoryString

The category field displays the category of the job. Corresponds to the JSON property jobCategory

Returns:

  • (String)


281
282
283
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 281

def job_category
  @job_category
end

#job_idString

The job_id field displays the identifier of the job being logged. Corresponds to the JSON property jobId

Returns:

  • (String)


286
287
288
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 286

def job_id
  @job_id
end

#job_statusString

The status field displays the status of the job. Corresponds to the JSON property jobStatus

Returns:

  • (String)


291
292
293
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 291

def job_status
  @job_status
end

#recovery_point_timeString

Recovery point time. Corresponds to the JSON property recoveryPointTime

Returns:

  • (String)


296
297
298
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 296

def recovery_point_time
  @recovery_point_time
end

#resource_typeString

The resource_type field displays the type of the protected resource. Corresponds to the JSON property resourceType

Returns:

  • (String)


301
302
303
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 301

def resource_type
  @resource_type
end

#restore_resource_locationString

Restore resource location. Corresponds to the JSON property restoreResourceLocation

Returns:

  • (String)


306
307
308
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 306

def restore_resource_location
  @restore_resource_location
end

#restore_resource_nameString

Full resource name of the restore resource. Only populated in restore jobs. Corresponds to the JSON property restoreResourceName

Returns:

  • (String)


311
312
313
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 311

def restore_resource_name
  @restore_resource_name
end

#source_resource_idString

The source resource ID. Corresponds to the JSON property sourceResourceId

Returns:

  • (String)


316
317
318
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 316

def source_resource_id
  @source_resource_id
end

#source_resource_locationString

Source resource location. Corresponds to the JSON property sourceResourceLocation

Returns:

  • (String)


321
322
323
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 321

def source_resource_location
  @source_resource_location
end

#source_resource_nameString

Full resource name of the protected resource. Corresponds to the JSON property sourceResourceName

Returns:

  • (String)


326
327
328
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 326

def source_resource_name
  @source_resource_name
end

#start_timeString

Start time of the job. Corresponds to the JSON property startTime

Returns:

  • (String)


331
332
333
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 331

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 338

def update!(**args)
  @backup_consistency_time = args[:backup_consistency_time] if args.key?(:backup_consistency_time)
  @backup_name = args[:backup_name] if args.key?(:backup_name)
  @backup_plan_name = args[:backup_plan_name] if args.key?(:backup_plan_name)
  @backup_retention_days = args[:backup_retention_days] if args.key?(:backup_retention_days)
  @backup_rule = args[:backup_rule] if args.key?(:backup_rule)
  @backup_vault_name = args[:backup_vault_name] if args.key?(:backup_vault_name)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error_code = args[:error_code] if args.key?(:error_code)
  @error_message = args[:error_message] if args.key?(:error_message)
  @error_type = args[:error_type] if args.key?(:error_type)
  @incremental_backup_size_gib = args[:incremental_backup_size_gib] if args.key?(:incremental_backup_size_gib)
  @job_category = args[:job_category] if args.key?(:job_category)
  @job_id = args[:job_id] if args.key?(:job_id)
  @job_status = args[:job_status] if args.key?(:job_status)
  @recovery_point_time = args[:recovery_point_time] if args.key?(:recovery_point_time)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @restore_resource_location = args[:restore_resource_location] if args.key?(:restore_resource_location)
  @restore_resource_name = args[:restore_resource_name] if args.key?(:restore_resource_name)
  @source_resource_id = args[:source_resource_id] if args.key?(:source_resource_id)
  @source_resource_location = args[:source_resource_location] if args.key?(:source_resource_location)
  @source_resource_name = args[:source_resource_name] if args.key?(:source_resource_name)
  @start_time = args[:start_time] if args.key?(:start_time)
end