Class: Google::Apis::GkebackupV1::ClusterResourceRestoreScope
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::ClusterResourceRestoreScope
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
Defines the scope of cluster-scoped resources to restore. Some group kinds are not reasonable choices for a restore, and will cause an error if selected here. Any scope selection that would restore "all valid" resources automatically excludes these group kinds. - Node - ComponentStatus - gkebackup.gke.io/ BackupJob - gkebackup.gke.io/RestoreJob - metrics.k8s.io/NodeMetrics - migration.k8s.io/StorageState - migration.k8s.io/StorageVersionMigration - snapshot.storage.k8s.io/VolumeSnapshotContent - storage.k8s.io/CSINode - storage.k8s.io/VolumeAttachment Some group kinds are driven by restore configuration elsewhere, and will cause an error if selected here. - Namespace
- PersistentVolume
Instance Attribute Summary collapse
-
#all_group_kinds ⇒ Boolean
(also: #all_group_kinds?)
Optional.
-
#excluded_group_kinds ⇒ Array<Google::Apis::GkebackupV1::GroupKind>
Optional.
-
#no_group_kinds ⇒ Boolean
(also: #no_group_kinds?)
Optional.
-
#selected_group_kinds ⇒ Array<Google::Apis::GkebackupV1::GroupKind>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClusterResourceRestoreScope
constructor
A new instance of ClusterResourceRestoreScope.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClusterResourceRestoreScope
Returns a new instance of ClusterResourceRestoreScope.
1386 1387 1388 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1386 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_group_kinds ⇒ Boolean Also known as: all_group_kinds?
Optional. If True, all valid cluster-scoped resources will be restored.
Mutually exclusive to any other field in the message.
Corresponds to the JSON property allGroupKinds
1360 1361 1362 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1360 def all_group_kinds @all_group_kinds end |
#excluded_group_kinds ⇒ Array<Google::Apis::GkebackupV1::GroupKind>
Optional. A list of cluster-scoped resource group kinds to NOT restore from
the backup. If specified, all valid cluster-scoped resources will be restored
except for those specified in the list. Mutually exclusive to any other field
in the message.
Corresponds to the JSON property excludedGroupKinds
1369 1370 1371 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1369 def excluded_group_kinds @excluded_group_kinds end |
#no_group_kinds ⇒ Boolean Also known as: no_group_kinds?
Optional. If True, no cluster-scoped resources will be restored. This has the
same restore scope as if the message is not defined. Mutually exclusive to any
other field in the message.
Corresponds to the JSON property noGroupKinds
1376 1377 1378 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1376 def no_group_kinds @no_group_kinds end |
#selected_group_kinds ⇒ Array<Google::Apis::GkebackupV1::GroupKind>
Optional. A list of cluster-scoped resource group kinds to restore from the
backup. If specified, only the selected resources will be restored. Mutually
exclusive to any other field in the message.
Corresponds to the JSON property selectedGroupKinds
1384 1385 1386 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1384 def selected_group_kinds @selected_group_kinds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1391 1392 1393 1394 1395 1396 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1391 def update!(**args) @all_group_kinds = args[:all_group_kinds] if args.key?(:all_group_kinds) @excluded_group_kinds = args[:excluded_group_kinds] if args.key?(:excluded_group_kinds) @no_group_kinds = args[:no_group_kinds] if args.key?(:no_group_kinds) @selected_group_kinds = args[:selected_group_kinds] if args.key?(:selected_group_kinds) end |