Class: Google::Apis::GkebackupV1::ClusterResourceRestoreScope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Defines the scope of cluster-scoped resources to restore. Some group kinds are not reasonable choices for a restore, and will cause an error if selected here. Any scope selection that would restore "all valid" resources automatically excludes these group kinds. - Node - ComponentStatus - gkebackup.gke.io/ BackupJob - gkebackup.gke.io/RestoreJob - metrics.k8s.io/NodeMetrics - migration.k8s.io/StorageState - migration.k8s.io/StorageVersionMigration - snapshot.storage.k8s.io/VolumeSnapshotContent - storage.k8s.io/CSINode - storage.k8s.io/VolumeAttachment Some group kinds are driven by restore configuration elsewhere, and will cause an error if selected here. - Namespace

  • PersistentVolume

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterResourceRestoreScope

Returns a new instance of ClusterResourceRestoreScope.



1354
1355
1356
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_group_kindsBoolean Also known as: all_group_kinds?

Optional. If True, all valid cluster-scoped resources will be restored. Mutually exclusive to any other field in the message. Corresponds to the JSON property allGroupKinds

Returns:

  • (Boolean)


1328
1329
1330
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1328

def all_group_kinds
  @all_group_kinds
end

#excluded_group_kindsArray<Google::Apis::GkebackupV1::GroupKind>

Optional. A list of cluster-scoped resource group kinds to NOT restore from the backup. If specified, all valid cluster-scoped resources will be restored except for those specified in the list. Mutually exclusive to any other field in the message. Corresponds to the JSON property excludedGroupKinds



1337
1338
1339
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1337

def excluded_group_kinds
  @excluded_group_kinds
end

#no_group_kindsBoolean Also known as: no_group_kinds?

Optional. If True, no cluster-scoped resources will be restored. This has the same restore scope as if the message is not defined. Mutually exclusive to any other field in the message. Corresponds to the JSON property noGroupKinds

Returns:

  • (Boolean)


1344
1345
1346
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1344

def no_group_kinds
  @no_group_kinds
end

#selected_group_kindsArray<Google::Apis::GkebackupV1::GroupKind>

Optional. A list of cluster-scoped resource group kinds to restore from the backup. If specified, only the selected resources will be restored. Mutually exclusive to any other field in the message. Corresponds to the JSON property selectedGroupKinds



1352
1353
1354
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1352

def selected_group_kinds
  @selected_group_kinds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1359
1360
1361
1362
1363
1364
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1359

def update!(**args)
  @all_group_kinds = args[:all_group_kinds] if args.key?(:all_group_kinds)
  @excluded_group_kinds = args[:excluded_group_kinds] if args.key?(:excluded_group_kinds)
  @no_group_kinds = args[:no_group_kinds] if args.key?(:no_group_kinds)
  @selected_group_kinds = args[:selected_group_kinds] if args.key?(:selected_group_kinds)
end