Class: Google::Apis::GkebackupV1::ExclusionWindow
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::ExclusionWindow
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
Defines a time window during which no backup should happen. All time and date are in UTC.
Instance Attribute Summary collapse
-
#daily ⇒ Boolean
(also: #daily?)
The exclusion window occurs every day if set to "True".
-
#days_of_week ⇒ Google::Apis::GkebackupV1::DayOfWeekList
Holds repeated DaysOfWeek values as a container.
-
#duration ⇒ String
Required.
-
#single_occurrence_date ⇒ Google::Apis::GkebackupV1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#start_time ⇒ Google::Apis::GkebackupV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExclusionWindow
constructor
A new instance of ExclusionWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExclusionWindow
Returns a new instance of ExclusionWindow.
1511 1512 1513 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1511 def initialize(**args) update!(**args) end |
Instance Attribute Details
#daily ⇒ Boolean Also known as: daily?
The exclusion window occurs every day if set to "True". Specifying this field
to "False" is an error.
Corresponds to the JSON property daily
1473 1474 1475 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1473 def daily @daily end |
#days_of_week ⇒ Google::Apis::GkebackupV1::DayOfWeekList
Holds repeated DaysOfWeek values as a container.
Corresponds to the JSON property daysOfWeek
1479 1480 1481 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1479 def days_of_week @days_of_week end |
#duration ⇒ String
Required. Specifies duration of the window. Duration must be >= 5 minutes and <
(target RPO - 20 minutes). Additional restrictions based on the recurrence
type to allow some time for backup to happen: - single_occurrence_date: no
restriction, but UI may warn about this when duration >= target RPO - daily
window: duration < 24 hours - weekly window: - days of week includes all seven
days of a week: duration < 24 hours - all other weekly window: duration < 168
hours (i.e., 24 * 7 hours)
Corresponds to the JSON property duration
1490 1491 1492 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1490 def duration @duration end |
#single_occurrence_date ⇒ Google::Apis::GkebackupV1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property singleOccurrenceDate
1502 1503 1504 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1502 def single_occurrence_date @single_occurrence_date end |
#start_time ⇒ Google::Apis::GkebackupV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
1509 1510 1511 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1509 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1516 1517 1518 1519 1520 1521 1522 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1516 def update!(**args) @daily = args[:daily] if args.key?(:daily) @days_of_week = args[:days_of_week] if args.key?(:days_of_week) @duration = args[:duration] if args.key?(:duration) @single_occurrence_date = args[:single_occurrence_date] if args.key?(:single_occurrence_date) @start_time = args[:start_time] if args.key?(:start_time) end |