Class: Google::Apis::GkebackupV1::GroupKindDependency

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Defines a dependency between two group kinds.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GroupKindDependency

Returns a new instance of GroupKindDependency.



1900
1901
1902
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1900

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#requiringGoogle::Apis::GkebackupV1::GroupKind

This is a direct map to the Kubernetes GroupKind type GroupKind and is used for identifying specific "types" of resources to restore. Corresponds to the JSON property requiring



1891
1892
1893
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1891

def requiring
  @requiring
end

#satisfyingGoogle::Apis::GkebackupV1::GroupKind

This is a direct map to the Kubernetes GroupKind type GroupKind and is used for identifying specific "types" of resources to restore. Corresponds to the JSON property satisfying



1898
1899
1900
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1898

def satisfying
  @satisfying
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1905
1906
1907
1908
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1905

def update!(**args)
  @requiring = args[:requiring] if args.key?(:requiring)
  @satisfying = args[:satisfying] if args.key?(:satisfying)
end