Class: Google::Apis::GkebackupV1::ListBackupChannelsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Response message for ListBackupChannels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupChannelsResponse

Returns a new instance of ListBackupChannelsResponse.



1963
1964
1965
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_channelsArray<Google::Apis::GkebackupV1::BackupChannel>

The list of BackupChannels matching the given criteria. Corresponds to the JSON property backupChannels



1949
1950
1951
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1949

def backup_channels
  @backup_channels
end

#next_page_tokenString

A token which may be sent as page_token in a subsequent ListBackupChannels call to retrieve the next page of results. If this field is omitted or empty, then there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1956
1957
1958
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1956

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1961
1962
1963
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1961

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1968
1969
1970
1971
1972
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1968

def update!(**args)
  @backup_channels = args[:backup_channels] if args.key?(:backup_channels)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end