Class: Google::Apis::GkebackupV1::ListBackupPlanBindingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Response message for ListBackupPlanBindings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupPlanBindingsResponse

Returns a new instance of ListBackupPlanBindingsResponse.



2002
2003
2004
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_plan_bindingsArray<Google::Apis::GkebackupV1::BackupPlanBinding>

The list of BackupPlanBindings matching the given criteria. Corresponds to the JSON property backupPlanBindings



1988
1989
1990
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1988

def backup_plan_bindings
  @backup_plan_bindings
end

#next_page_tokenString

A token which may be sent as page_token in a subsequent ListBackupPlanBindingss call to retrieve the next page of results. If this field is omitted or empty, then there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1995
1996
1997
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1995

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2000
2001
2002
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2000

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2007
2008
2009
2010
2011
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2007

def update!(**args)
  @backup_plan_bindings = args[:backup_plan_bindings] if args.key?(:backup_plan_bindings)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end