Class: Google::Apis::GkebackupV1::ListBackupPlanBindingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Response message for ListBackupPlanBindings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupPlanBindingsResponse

Returns a new instance of ListBackupPlanBindingsResponse.



1996
1997
1998
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1996

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_plan_bindingsArray<Google::Apis::GkebackupV1::BackupPlanBinding>

The list of BackupPlanBindings matching the given criteria. Corresponds to the JSON property backupPlanBindings



1982
1983
1984
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1982

def backup_plan_bindings
  @backup_plan_bindings
end

#next_page_tokenString

A token which may be sent as page_token in a subsequent ListBackupPlanBindingss call to retrieve the next page of results. If this field is omitted or empty, then there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1989
1990
1991
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1989

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1994
1995
1996
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1994

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2001
2002
2003
2004
2005
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2001

def update!(**args)
  @backup_plan_bindings = args[:backup_plan_bindings] if args.key?(:backup_plan_bindings)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end