Class: Google::Apis::GkebackupV1::ListBackupPlanBindingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::ListBackupPlanBindingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
Response message for ListBackupPlanBindings.
Instance Attribute Summary collapse
-
#backup_plan_bindings ⇒ Array<Google::Apis::GkebackupV1::BackupPlanBinding>
The list of BackupPlanBindings matching the given criteria.
-
#next_page_token ⇒ String
A token which may be sent as page_token in a subsequent
ListBackupPlanBindingsscall to retrieve the next page of results. -
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBackupPlanBindingsResponse
constructor
A new instance of ListBackupPlanBindingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBackupPlanBindingsResponse
Returns a new instance of ListBackupPlanBindingsResponse.
1990 1991 1992 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1990 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_plan_bindings ⇒ Array<Google::Apis::GkebackupV1::BackupPlanBinding>
The list of BackupPlanBindings matching the given criteria.
Corresponds to the JSON property backupPlanBindings
1976 1977 1978 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1976 def backup_plan_bindings @backup_plan_bindings end |
#next_page_token ⇒ String
A token which may be sent as page_token in a subsequent
ListBackupPlanBindingss call to retrieve the next page of results. If this
field is omitted or empty, then there are no more results to return.
Corresponds to the JSON property nextPageToken
1983 1984 1985 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1983 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1988 1989 1990 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1988 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1995 1996 1997 1998 1999 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1995 def update!(**args) @backup_plan_bindings = args[:backup_plan_bindings] if args.key?(:backup_plan_bindings) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |