Class: Google::Apis::GkebackupV1::ListBackupPlansResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Response message for ListBackupPlans.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupPlansResponse

Returns a new instance of ListBackupPlansResponse.



2023
2024
2025
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2023

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_plansArray<Google::Apis::GkebackupV1::BackupPlan>

The list of BackupPlans matching the given criteria. Corresponds to the JSON property backupPlans



2009
2010
2011
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2009

def backup_plans
  @backup_plans
end

#next_page_tokenString

A token which may be sent as page_token in a subsequent ListBackupPlans call to retrieve the next page of results. If this field is omitted or empty, then there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2016
2017
2018
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2016

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2021
2022
2023
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2021

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2028
2029
2030
2031
2032
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2028

def update!(**args)
  @backup_plans = args[:backup_plans] if args.key?(:backup_plans)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end