Class: Google::Apis::GkebackupV1::ListBackupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Response message for ListBackups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupsResponse

Returns a new instance of ListBackupsResponse.



2056
2057
2058
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2056

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupsArray<Google::Apis::GkebackupV1::Backup>

The list of Backups matching the given criteria. Corresponds to the JSON property backups



2042
2043
2044
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2042

def backups
  @backups
end

#next_page_tokenString

A token which may be sent as page_token in a subsequent ListBackups call to retrieve the next page of results. If this field is omitted or empty, then there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2049
2050
2051
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2049

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2054
2055
2056
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2054

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2061
2062
2063
2064
2065
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2061

def update!(**args)
  @backups = args[:backups] if args.key?(:backups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end