Class: Google::Apis::GkebackupV1::ListBackupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Response message for ListBackups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupsResponse

Returns a new instance of ListBackupsResponse.



2017
2018
2019
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2017

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupsArray<Google::Apis::GkebackupV1::Backup>

The list of Backups matching the given criteria. Corresponds to the JSON property backups



2003
2004
2005
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2003

def backups
  @backups
end

#next_page_tokenString

A token which may be sent as page_token in a subsequent ListBackups call to retrieve the next page of results. If this field is omitted or empty, then there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2010
2011
2012
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2010

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2015
2016
2017
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2015

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2022
2023
2024
2025
2026
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2022

def update!(**args)
  @backups = args[:backups] if args.key?(:backups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end