Class: Google::Apis::GkebackupV1::ListRestoreChannelsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Response message for ListRestoreChannels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListRestoreChannelsResponse

Returns a new instance of ListRestoreChannelsResponse.



2114
2115
2116
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2114

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token which may be sent as page_token in a subsequent ListRestoreChannels call to retrieve the next page of results. If this field is omitted or empty, then there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2102
2103
2104
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2102

def next_page_token
  @next_page_token
end

#restore_channelsArray<Google::Apis::GkebackupV1::RestoreChannel>

The list of RestoreChannels matching the given criteria. Corresponds to the JSON property restoreChannels



2107
2108
2109
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2107

def restore_channels
  @restore_channels
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2112
2113
2114
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2112

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2119
2120
2121
2122
2123
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2119

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @restore_channels = args[:restore_channels] if args.key?(:restore_channels)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end