Class: Google::Apis::GkebackupV1::ListRestorePlanBindingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Response message for ListRestorePlanBindings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListRestorePlanBindingsResponse

Returns a new instance of ListRestorePlanBindingsResponse.



2153
2154
2155
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2153

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token which may be sent as page_token in a subsequent ListRestorePlanBindings call to retrieve the next page of results. If this field is omitted or empty, then there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2141
2142
2143
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2141

def next_page_token
  @next_page_token
end

#restore_plan_bindingsArray<Google::Apis::GkebackupV1::RestorePlanBinding>

The list of RestorePlanBindings matching the given criteria. Corresponds to the JSON property restorePlanBindings



2146
2147
2148
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2146

def restore_plan_bindings
  @restore_plan_bindings
end

#unreachableArray<String>

Unordered list. Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2151
2152
2153
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2151

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2158
2159
2160
2161
2162
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2158

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @restore_plan_bindings = args[:restore_plan_bindings] if args.key?(:restore_plan_bindings)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end