Class: Google::Apis::GkebackupV1::ListRestorePlanBindingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::ListRestorePlanBindingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
Response message for ListRestorePlanBindings.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token which may be sent as page_token in a subsequent
ListRestorePlanBindingscall to retrieve the next page of results. -
#restore_plan_bindings ⇒ Array<Google::Apis::GkebackupV1::RestorePlanBinding>
The list of RestorePlanBindings matching the given criteria.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRestorePlanBindingsResponse
constructor
A new instance of ListRestorePlanBindingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRestorePlanBindingsResponse
Returns a new instance of ListRestorePlanBindingsResponse.
2147 2148 2149 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2147 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token which may be sent as page_token in a subsequent
ListRestorePlanBindings call to retrieve the next page of results. If this
field is omitted or empty, then there are no more results to return.
Corresponds to the JSON property nextPageToken
2135 2136 2137 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2135 def next_page_token @next_page_token end |
#restore_plan_bindings ⇒ Array<Google::Apis::GkebackupV1::RestorePlanBinding>
The list of RestorePlanBindings matching the given criteria.
Corresponds to the JSON property restorePlanBindings
2140 2141 2142 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2140 def restore_plan_bindings @restore_plan_bindings end |
#unreachable ⇒ Array<String>
Unordered list. Locations that could not be reached.
Corresponds to the JSON property unreachable
2145 2146 2147 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2145 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2152 2153 2154 2155 2156 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2152 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @restore_plan_bindings = args[:restore_plan_bindings] if args.key?(:restore_plan_bindings) @unreachable = args[:unreachable] if args.key?(:unreachable) end |