Class: Google::Apis::GkebackupV1::ListRestorePlanBindingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::ListRestorePlanBindingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
Response message for ListRestorePlanBindings.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token which may be sent as page_token in a subsequent
ListRestorePlanBindingscall to retrieve the next page of results. -
#restore_plan_bindings ⇒ Array<Google::Apis::GkebackupV1::RestorePlanBinding>
The list of RestorePlanBindings matching the given criteria.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRestorePlanBindingsResponse
constructor
A new instance of ListRestorePlanBindingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRestorePlanBindingsResponse
Returns a new instance of ListRestorePlanBindingsResponse.
1757 1758 1759 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1757 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token which may be sent as page_token in a subsequent
ListRestorePlanBindings call to retrieve the next page of results. If this
field is omitted or empty, then there are no more results to return.
Corresponds to the JSON property nextPageToken
1745 1746 1747 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1745 def next_page_token @next_page_token end |
#restore_plan_bindings ⇒ Array<Google::Apis::GkebackupV1::RestorePlanBinding>
The list of RestorePlanBindings matching the given criteria.
Corresponds to the JSON property restorePlanBindings
1750 1751 1752 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1750 def restore_plan_bindings @restore_plan_bindings end |
#unreachable ⇒ Array<String>
Unordered list. Locations that could not be reached.
Corresponds to the JSON property unreachable
1755 1756 1757 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1755 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1762 1763 1764 1765 1766 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1762 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @restore_plan_bindings = args[:restore_plan_bindings] if args.key?(:restore_plan_bindings) @unreachable = args[:unreachable] if args.key?(:unreachable) end |