Class: Google::Apis::GkebackupV1::ListRestorePlansResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Response message for ListRestorePlans.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListRestorePlansResponse

Returns a new instance of ListRestorePlansResponse.



2180
2181
2182
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2180

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token which may be sent as page_token in a subsequent ListRestorePlans call to retrieve the next page of results. If this field is omitted or empty, then there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2168
2169
2170
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2168

def next_page_token
  @next_page_token
end

#restore_plansArray<Google::Apis::GkebackupV1::RestorePlan>

The list of RestorePlans matching the given criteria. Corresponds to the JSON property restorePlans



2173
2174
2175
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2173

def restore_plans
  @restore_plans
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2178
2179
2180
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2178

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2185
2186
2187
2188
2189
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2185

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @restore_plans = args[:restore_plans] if args.key?(:restore_plans)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end