Class: Google::Apis::GkebackupV1::ListRestorePlansResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Response message for ListRestorePlans.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListRestorePlansResponse

Returns a new instance of ListRestorePlansResponse.



1790
1791
1792
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1790

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token which may be sent as page_token in a subsequent ListRestorePlans call to retrieve the next page of results. If this field is omitted or empty, then there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1778
1779
1780
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1778

def next_page_token
  @next_page_token
end

#restore_plansArray<Google::Apis::GkebackupV1::RestorePlan>

The list of RestorePlans matching the given criteria. Corresponds to the JSON property restorePlans



1783
1784
1785
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1783

def restore_plans
  @restore_plans
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1788
1789
1790
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1788

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1795
1796
1797
1798
1799
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1795

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @restore_plans = args[:restore_plans] if args.key?(:restore_plans)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end