Class: Google::Apis::GkebackupV1::ListRestoresResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Response message for ListRestores.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListRestoresResponse

Returns a new instance of ListRestoresResponse.



1823
1824
1825
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1823

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token which may be sent as page_token in a subsequent ListRestores call to retrieve the next page of results. If this field is omitted or empty, then there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1811
1812
1813
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1811

def next_page_token
  @next_page_token
end

#restoresArray<Google::Apis::GkebackupV1::Restore>

The list of Restores matching the given criteria. Corresponds to the JSON property restores



1816
1817
1818
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1816

def restores
  @restores
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1821
1822
1823
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1821

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1828
1829
1830
1831
1832
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1828

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @restores = args[:restores] if args.key?(:restores)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end