Class: Google::Apis::GkebackupV1::ListVolumeBackupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Response message for ListVolumeBackups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListVolumeBackupsResponse

Returns a new instance of ListVolumeBackupsResponse.



1851
1852
1853
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1851

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token which may be sent as page_token in a subsequent ListVolumeBackups call to retrieve the next page of results. If this field is omitted or empty, then there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1844
1845
1846
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1844

def next_page_token
  @next_page_token
end

#volume_backupsArray<Google::Apis::GkebackupV1::VolumeBackup>

The list of VolumeBackups matching the given criteria. Corresponds to the JSON property volumeBackups



1849
1850
1851
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1849

def volume_backups
  @volume_backups
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1856
1857
1858
1859
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1856

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @volume_backups = args[:volume_backups] if args.key?(:volume_backups)
end