Class: Google::Apis::GkebackupV1::ListVolumeRestoresResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Response message for ListVolumeRestores.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListVolumeRestoresResponse

Returns a new instance of ListVolumeRestoresResponse.



2268
2269
2270
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2268

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token which may be sent as page_token in a subsequent ListVolumeRestores call to retrieve the next page of results. If this field is omitted or empty, then there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2261
2262
2263
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2261

def next_page_token
  @next_page_token
end

#volume_restoresArray<Google::Apis::GkebackupV1::VolumeRestore>

The list of VolumeRestores matching the given criteria. Corresponds to the JSON property volumeRestores



2266
2267
2268
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2266

def volume_restores
  @volume_restores
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2273
2274
2275
2276
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2273

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @volume_restores = args[:volume_restores] if args.key?(:volume_restores)
end