Class: Google::Apis::GkebackupV1::ListVolumeRestoresResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Response message for ListVolumeRestores.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListVolumeRestoresResponse

Returns a new instance of ListVolumeRestoresResponse.



1878
1879
1880
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1878

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token which may be sent as page_token in a subsequent ListVolumeRestores call to retrieve the next page of results. If this field is omitted or empty, then there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1871
1872
1873
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1871

def next_page_token
  @next_page_token
end

#volume_restoresArray<Google::Apis::GkebackupV1::VolumeRestore>

The list of VolumeRestores matching the given criteria. Corresponds to the JSON property volumeRestores



1876
1877
1878
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1876

def volume_restores
  @volume_restores
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1883
1884
1885
1886
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 1883

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @volume_restores = args[:volume_restores] if args.key?(:volume_restores)
end