Class: Google::Apis::GkebackupV1::ResourceFilter
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::ResourceFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
ResourceFilter specifies matching criteria to limit the scope of a change to a specific set of kubernetes resources that are selected for restoration from a backup.
Instance Attribute Summary collapse
-
#group_kinds ⇒ Array<Google::Apis::GkebackupV1::GroupKind>
Optional.
-
#json_path ⇒ String
Optional.
-
#namespaces ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceFilter
constructor
A new instance of ResourceFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceFilter
Returns a new instance of ResourceFilter.
2535 2536 2537 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2535 def initialize(**args) update!(**args) end |
Instance Attribute Details
#group_kinds ⇒ Array<Google::Apis::GkebackupV1::GroupKind>
Optional. (Filtering parameter) Any resource subject to transformation must
belong to one of the listed "types". If this field is not provided, no type
filtering will be performed (all resources of all types matching previous
filtering parameters will be candidates for transformation).
Corresponds to the JSON property groupKinds
2516 2517 2518 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2516 def group_kinds @group_kinds end |
#json_path ⇒ String
Optional. This is a JSONPath expression that matches specific fields of candidate
resources and it operates as a filtering parameter (resources that are not
matched with this expression will not be candidates for transformation).
Corresponds to the JSON property jsonPath
2524 2525 2526 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2524 def json_path @json_path end |
#namespaces ⇒ Array<String>
Optional. (Filtering parameter) Any resource subject to transformation must be
contained within one of the listed Kubernetes Namespace in the Backup. If this
field is not provided, no namespace filtering will be performed (all resources
in all Namespaces, including all cluster-scoped resources, will be candidates
for transformation).
Corresponds to the JSON property namespaces
2533 2534 2535 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2533 def namespaces @namespaces end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2540 2541 2542 2543 2544 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2540 def update!(**args) @group_kinds = args[:group_kinds] if args.key?(:group_kinds) @json_path = args[:json_path] if args.key?(:json_path) @namespaces = args[:namespaces] if args.key?(:namespaces) end |