Class: Google::Apis::GkebackupV1::ResourceSelector
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::ResourceSelector
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
Defines a selector to identify a single or a group of resources. Conditions in the selector are optional, but at least one field should be set to a non-empty value. If a condition is not specified, no restrictions will be applied on that dimension. If more than one condition is specified, a resource will be selected if and only if all conditions are met.
Instance Attribute Summary collapse
-
#group_kind ⇒ Google::Apis::GkebackupV1::GroupKind
This is a direct map to the Kubernetes GroupKind type GroupKind and is used for identifying specific "types" of resources to restore.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Optional.
-
#namespace ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceSelector
constructor
A new instance of ResourceSelector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceSelector
Returns a new instance of ResourceSelector.
2606 2607 2608 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2606 def initialize(**args) update!(**args) end |
Instance Attribute Details
#group_kind ⇒ Google::Apis::GkebackupV1::GroupKind
This is a direct map to the Kubernetes GroupKind type GroupKind and is used for
identifying specific "types" of resources to restore.
Corresponds to the JSON property groupKind
2579 2580 2581 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2579 def group_kind @group_kind end |
#labels ⇒ Hash<String,String>
Optional. Selects resources using Kubernetes labels. If specified, a resource
will be selected if and only if the resource has all of the provided labels
and all the label values match.
Corresponds to the JSON property labels
2587 2588 2589 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2587 def labels @labels end |
#name ⇒ String
Optional. Selects resources using their resource names. If specified, only
resources with the provided name will be selected.
Corresponds to the JSON property name
2593 2594 2595 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2593 def name @name end |
#namespace ⇒ String
Optional. Selects resources using their namespaces. This only applies to
namespace scoped resources and cannot be used for selecting cluster scoped
resources. If specified, only resources in the provided namespace will be
selected. If not specified, the filter will apply to both cluster scoped and
namespace scoped resources (e.g. name or label). The Namespace resource itself will be restored if and
only if any resources within the namespace are restored.
Corresponds to the JSON property namespace
2604 2605 2606 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2604 def namespace @namespace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2611 2612 2613 2614 2615 2616 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2611 def update!(**args) @group_kind = args[:group_kind] if args.key?(:group_kind) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @namespace = args[:namespace] if args.key?(:namespace) end |