Class: Google::Apis::GkebackupV1::Restore
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::Restore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
Represents both a request to Restore some portion of a Backup into a target GKE cluster and a record of the restore operation itself.
Instance Attribute Summary collapse
-
#backup ⇒ String
Required.
-
#cluster ⇒ String
Output only.
-
#complete_time ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#filter ⇒ Google::Apis::GkebackupV1::Filter
Defines the filter for
Restore. -
#labels ⇒ Hash<String,String>
A set of custom labels supplied by user.
-
#name ⇒ String
Output only.
-
#resources_excluded_count ⇒ Fixnum
Output only.
-
#resources_failed_count ⇒ Fixnum
Output only.
-
#resources_restored_count ⇒ Fixnum
Output only.
-
#restore_config ⇒ Google::Apis::GkebackupV1::RestoreConfig
Configuration of a restore.
-
#state ⇒ String
Output only.
-
#state_reason ⇒ String
Output only.
-
#troubleshooting_info ⇒ Google::Apis::GkebackupV1::TroubleshootingInfo
Stores information about troubleshooting doc for debugging a particular state of an operation (eg - backup/restore).
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#volume_data_restore_policy_overrides ⇒ Array<Google::Apis::GkebackupV1::VolumeDataRestorePolicyOverride>
Optional.
-
#volumes_restored_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Restore
constructor
A new instance of Restore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Restore
Returns a new instance of Restore.
2786 2787 2788 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2786 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup ⇒ String
Required. Immutable. A reference to the Backup used as the source from which
this Restore will restore. Note that this Backup must be a sub-resource of the
RestorePlan's backup_plan. Format: projects/*/locations/*/backupPlans/*/
backups/*.
Corresponds to the JSON property backup
2669 2670 2671 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2669 def backup @backup end |
#cluster ⇒ String
Output only. The target cluster into which this Restore will restore data.
Valid formats: - projects/*/locations/*/clusters/* - projects/*/zones/*/
clusters/* Inherited from parent RestorePlan's cluster value.
Corresponds to the JSON property cluster
2676 2677 2678 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2676 def cluster @cluster end |
#complete_time ⇒ String
Output only. Timestamp of when the restore operation completed.
Corresponds to the JSON property completeTime
2681 2682 2683 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2681 def complete_time @complete_time end |
#create_time ⇒ String
Output only. The timestamp when this Restore resource was created.
Corresponds to the JSON property createTime
2686 2687 2688 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2686 def create_time @create_time end |
#description ⇒ String
Optional. User specified descriptive string for this Restore.
Corresponds to the JSON property description
2691 2692 2693 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2691 def description @description end |
#etag ⇒ String
Output only. etag is used for optimistic concurrency control as a way to
help prevent simultaneous updates of a restore from overwriting each other. It
is strongly suggested that systems make use of the etag in the read-modify-
write cycle to perform restore updates in order to avoid race conditions: An
etag is returned in the response to GetRestore, and systems are expected to
put that etag in the request to UpdateRestore or DeleteRestore to ensure
that their change will be applied to the same version of the resource.
Corresponds to the JSON property etag
2702 2703 2704 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2702 def etag @etag end |
#filter ⇒ Google::Apis::GkebackupV1::Filter
Defines the filter for Restore. This filter can be used to further refine
the resource selection of the Restore beyond the coarse-grained scope
defined in the RestorePlan. exclusion_filters take precedence over
inclusion_filters. If a resource matches both inclusion_filters and
exclusion_filters, it will not be restored.
Corresponds to the JSON property filter
2711 2712 2713 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2711 def filter @filter end |
#labels ⇒ Hash<String,String>
A set of custom labels supplied by user.
Corresponds to the JSON property labels
2716 2717 2718 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2716 def labels @labels end |
#name ⇒ String
Output only. Identifier. The full name of the Restore resource. Format:
projects/*/locations/*/restorePlans/*/restores/*
Corresponds to the JSON property name
2722 2723 2724 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2722 def name @name end |
#resources_excluded_count ⇒ Fixnum
Output only. Number of resources excluded during the restore execution.
Corresponds to the JSON property resourcesExcludedCount
2727 2728 2729 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2727 def resources_excluded_count @resources_excluded_count end |
#resources_failed_count ⇒ Fixnum
Output only. Number of resources that failed to be restored during the restore
execution.
Corresponds to the JSON property resourcesFailedCount
2733 2734 2735 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2733 def resources_failed_count @resources_failed_count end |
#resources_restored_count ⇒ Fixnum
Output only. Number of resources restored during the restore execution.
Corresponds to the JSON property resourcesRestoredCount
2738 2739 2740 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2738 def resources_restored_count @resources_restored_count end |
#restore_config ⇒ Google::Apis::GkebackupV1::RestoreConfig
Configuration of a restore.
Corresponds to the JSON property restoreConfig
2743 2744 2745 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2743 def restore_config @restore_config end |
#state ⇒ String
Output only. The current state of the Restore.
Corresponds to the JSON property state
2748 2749 2750 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2748 def state @state end |
#state_reason ⇒ String
Output only. Human-readable description of why the Restore is in its current
state. This field is only meant for human readability and should not be used
programmatically as this field is not guaranteed to be consistent.
Corresponds to the JSON property stateReason
2755 2756 2757 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2755 def state_reason @state_reason end |
#troubleshooting_info ⇒ Google::Apis::GkebackupV1::TroubleshootingInfo
Stores information about troubleshooting doc for debugging a particular state
of an operation (eg - backup/restore). This will be used by the end user to
debug their operation failure scenario easily.
Corresponds to the JSON property troubleshootingInfo
2762 2763 2764 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2762 def troubleshooting_info @troubleshooting_info end |
#uid ⇒ String
Output only. Server generated global unique identifier of UUID format.
Corresponds to the JSON property uid
2768 2769 2770 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2768 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when this Restore resource was last updated.
Corresponds to the JSON property updateTime
2773 2774 2775 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2773 def update_time @update_time end |
#volume_data_restore_policy_overrides ⇒ Array<Google::Apis::GkebackupV1::VolumeDataRestorePolicyOverride>
Optional. Immutable. Overrides the volume data restore policies selected in
the Restore Config for override-scoped resources.
Corresponds to the JSON property volumeDataRestorePolicyOverrides
2779 2780 2781 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2779 def volume_data_restore_policy_overrides @volume_data_restore_policy_overrides end |
#volumes_restored_count ⇒ Fixnum
Output only. Number of volumes restored during the restore execution.
Corresponds to the JSON property volumesRestoredCount
2784 2785 2786 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2784 def volumes_restored_count @volumes_restored_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2791 2792 2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2791 def update!(**args) @backup = args[:backup] if args.key?(:backup) @cluster = args[:cluster] if args.key?(:cluster) @complete_time = args[:complete_time] if args.key?(:complete_time) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @filter = args[:filter] if args.key?(:filter) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @resources_excluded_count = args[:resources_excluded_count] if args.key?(:resources_excluded_count) @resources_failed_count = args[:resources_failed_count] if args.key?(:resources_failed_count) @resources_restored_count = args[:resources_restored_count] if args.key?(:resources_restored_count) @restore_config = args[:restore_config] if args.key?(:restore_config) @state = args[:state] if args.key?(:state) @state_reason = args[:state_reason] if args.key?(:state_reason) @troubleshooting_info = args[:troubleshooting_info] if args.key?(:troubleshooting_info) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @volume_data_restore_policy_overrides = args[:volume_data_restore_policy_overrides] if args.key?(:volume_data_restore_policy_overrides) @volumes_restored_count = args[:volumes_restored_count] if args.key?(:volumes_restored_count) end |