Class: Google::Apis::GkebackupV1::Restore
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::Restore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
Represents both a request to Restore some portion of a Backup into a target GKE cluster and a record of the restore operation itself.
Instance Attribute Summary collapse
-
#backup ⇒ String
Required.
-
#cluster ⇒ String
Output only.
-
#complete_time ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#filter ⇒ Google::Apis::GkebackupV1::Filter
Defines the filter for
Restore. -
#labels ⇒ Hash<String,String>
A set of custom labels supplied by user.
-
#name ⇒ String
Output only.
-
#resources_excluded_count ⇒ Fixnum
Output only.
-
#resources_failed_count ⇒ Fixnum
Output only.
-
#resources_restored_count ⇒ Fixnum
Output only.
-
#restore_config ⇒ Google::Apis::GkebackupV1::RestoreConfig
Configuration of a restore.
-
#state ⇒ String
Output only.
-
#state_reason ⇒ String
Output only.
-
#troubleshooting_info ⇒ Google::Apis::GkebackupV1::TroubleshootingInfo
Stores information about troubleshooting doc for debugging a particular state of an operation (eg - backup/restore).
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#volume_data_restore_policy_overrides ⇒ Array<Google::Apis::GkebackupV1::VolumeDataRestorePolicyOverride>
Optional.
-
#volumes_restored_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Restore
constructor
A new instance of Restore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Restore
Returns a new instance of Restore.
2747 2748 2749 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2747 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup ⇒ String
Required. Immutable. A reference to the Backup used as the source from which
this Restore will restore. Note that this Backup must be a sub-resource of the
RestorePlan's backup_plan. Format: projects/*/locations/*/backupPlans/*/
backups/*.
Corresponds to the JSON property backup
2630 2631 2632 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2630 def backup @backup end |
#cluster ⇒ String
Output only. The target cluster into which this Restore will restore data.
Valid formats: - projects/*/locations/*/clusters/* - projects/*/zones/*/
clusters/* Inherited from parent RestorePlan's cluster value.
Corresponds to the JSON property cluster
2637 2638 2639 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2637 def cluster @cluster end |
#complete_time ⇒ String
Output only. Timestamp of when the restore operation completed.
Corresponds to the JSON property completeTime
2642 2643 2644 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2642 def complete_time @complete_time end |
#create_time ⇒ String
Output only. The timestamp when this Restore resource was created.
Corresponds to the JSON property createTime
2647 2648 2649 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2647 def create_time @create_time end |
#description ⇒ String
Optional. User specified descriptive string for this Restore.
Corresponds to the JSON property description
2652 2653 2654 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2652 def description @description end |
#etag ⇒ String
Output only. etag is used for optimistic concurrency control as a way to
help prevent simultaneous updates of a restore from overwriting each other. It
is strongly suggested that systems make use of the etag in the read-modify-
write cycle to perform restore updates in order to avoid race conditions: An
etag is returned in the response to GetRestore, and systems are expected to
put that etag in the request to UpdateRestore or DeleteRestore to ensure
that their change will be applied to the same version of the resource.
Corresponds to the JSON property etag
2663 2664 2665 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2663 def etag @etag end |
#filter ⇒ Google::Apis::GkebackupV1::Filter
Defines the filter for Restore. This filter can be used to further refine
the resource selection of the Restore beyond the coarse-grained scope
defined in the RestorePlan. exclusion_filters take precedence over
inclusion_filters. If a resource matches both inclusion_filters and
exclusion_filters, it will not be restored.
Corresponds to the JSON property filter
2672 2673 2674 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2672 def filter @filter end |
#labels ⇒ Hash<String,String>
A set of custom labels supplied by user.
Corresponds to the JSON property labels
2677 2678 2679 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2677 def labels @labels end |
#name ⇒ String
Output only. Identifier. The full name of the Restore resource. Format:
projects/*/locations/*/restorePlans/*/restores/*
Corresponds to the JSON property name
2683 2684 2685 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2683 def name @name end |
#resources_excluded_count ⇒ Fixnum
Output only. Number of resources excluded during the restore execution.
Corresponds to the JSON property resourcesExcludedCount
2688 2689 2690 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2688 def resources_excluded_count @resources_excluded_count end |
#resources_failed_count ⇒ Fixnum
Output only. Number of resources that failed to be restored during the restore
execution.
Corresponds to the JSON property resourcesFailedCount
2694 2695 2696 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2694 def resources_failed_count @resources_failed_count end |
#resources_restored_count ⇒ Fixnum
Output only. Number of resources restored during the restore execution.
Corresponds to the JSON property resourcesRestoredCount
2699 2700 2701 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2699 def resources_restored_count @resources_restored_count end |
#restore_config ⇒ Google::Apis::GkebackupV1::RestoreConfig
Configuration of a restore.
Corresponds to the JSON property restoreConfig
2704 2705 2706 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2704 def restore_config @restore_config end |
#state ⇒ String
Output only. The current state of the Restore.
Corresponds to the JSON property state
2709 2710 2711 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2709 def state @state end |
#state_reason ⇒ String
Output only. Human-readable description of why the Restore is in its current
state. This field is only meant for human readability and should not be used
programmatically as this field is not guaranteed to be consistent.
Corresponds to the JSON property stateReason
2716 2717 2718 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2716 def state_reason @state_reason end |
#troubleshooting_info ⇒ Google::Apis::GkebackupV1::TroubleshootingInfo
Stores information about troubleshooting doc for debugging a particular state
of an operation (eg - backup/restore). This will be used by the end user to
debug their operation failure scenario easily.
Corresponds to the JSON property troubleshootingInfo
2723 2724 2725 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2723 def troubleshooting_info @troubleshooting_info end |
#uid ⇒ String
Output only. Server generated global unique identifier of UUID format.
Corresponds to the JSON property uid
2729 2730 2731 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2729 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when this Restore resource was last updated.
Corresponds to the JSON property updateTime
2734 2735 2736 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2734 def update_time @update_time end |
#volume_data_restore_policy_overrides ⇒ Array<Google::Apis::GkebackupV1::VolumeDataRestorePolicyOverride>
Optional. Immutable. Overrides the volume data restore policies selected in
the Restore Config for override-scoped resources.
Corresponds to the JSON property volumeDataRestorePolicyOverrides
2740 2741 2742 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2740 def volume_data_restore_policy_overrides @volume_data_restore_policy_overrides end |
#volumes_restored_count ⇒ Fixnum
Output only. Number of volumes restored during the restore execution.
Corresponds to the JSON property volumesRestoredCount
2745 2746 2747 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2745 def volumes_restored_count @volumes_restored_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2752 2753 2754 2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 2769 2770 2771 2772 2773 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2752 def update!(**args) @backup = args[:backup] if args.key?(:backup) @cluster = args[:cluster] if args.key?(:cluster) @complete_time = args[:complete_time] if args.key?(:complete_time) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @filter = args[:filter] if args.key?(:filter) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @resources_excluded_count = args[:resources_excluded_count] if args.key?(:resources_excluded_count) @resources_failed_count = args[:resources_failed_count] if args.key?(:resources_failed_count) @resources_restored_count = args[:resources_restored_count] if args.key?(:resources_restored_count) @restore_config = args[:restore_config] if args.key?(:restore_config) @state = args[:state] if args.key?(:state) @state_reason = args[:state_reason] if args.key?(:state_reason) @troubleshooting_info = args[:troubleshooting_info] if args.key?(:troubleshooting_info) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @volume_data_restore_policy_overrides = args[:volume_data_restore_policy_overrides] if args.key?(:volume_data_restore_policy_overrides) @volumes_restored_count = args[:volumes_restored_count] if args.key?(:volumes_restored_count) end |