Class: Google::Apis::GkebackupV1::RestoreChannel
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::RestoreChannel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
A RestoreChannel imposes constraints on where backups can be restored. The
RestoreChannel should be in the same project and region as the backups. The
backups can only be restored in the destination_project.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#destination_project ⇒ String
Required.
-
#destination_project_id ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RestoreChannel
constructor
A new instance of RestoreChannel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RestoreChannel
Returns a new instance of RestoreChannel.
2890 2891 2892 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2890 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when this RestoreChannel was created.
Corresponds to the JSON property createTime
2836 2837 2838 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2836 def create_time @create_time end |
#description ⇒ String
Optional. User specified descriptive string for this RestoreChannel.
Corresponds to the JSON property description
2841 2842 2843 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2841 def description @description end |
#destination_project ⇒ String
Required. Immutable. The project into which the backups will be restored. The
format is projects/projectIdor `projects/`projectNumber.
Corresponds to the JSON property destinationProject
2847 2848 2849 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2847 def destination_project @destination_project end |
#destination_project_id ⇒ String
Output only. The project_id where backups will be restored. Example Project ID:
"my-project-id". This will be an OUTPUT_ONLY field to return the project_id
of the destination project.
Corresponds to the JSON property destinationProjectId
2854 2855 2856 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2854 def destination_project_id @destination_project_id end |
#etag ⇒ String
Output only. etag is used for optimistic concurrency control as a way to
help prevent simultaneous updates of a RestoreChannel from overwriting each
other. It is strongly suggested that systems make use of the 'etag' in the
read-modify-write cycle to perform RestoreChannel updates in order to avoid
race conditions: An etag is returned in the response to GetRestoreChannel,
and systems are expected to put that etag in the request to
UpdateRestoreChannel or DeleteRestoreChannel to ensure that their change
will be applied to the same version of the resource.
Corresponds to the JSON property etag
2866 2867 2868 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2866 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. A set of custom labels supplied by user.
Corresponds to the JSON property labels
2871 2872 2873 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2871 def labels @labels end |
#name ⇒ String
Identifier. The fully qualified name of the RestoreChannel. projects/*/
locations/*/restoreChannels/*
Corresponds to the JSON property name
2877 2878 2879 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2877 def name @name end |
#uid ⇒ String
Output only. Server generated global unique identifier of UUID format.
Corresponds to the JSON property uid
2883 2884 2885 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2883 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when this RestoreChannel was last updated.
Corresponds to the JSON property updateTime
2888 2889 2890 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2888 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2895 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @destination_project = args[:destination_project] if args.key?(:destination_project) @destination_project_id = args[:destination_project_id] if args.key?(:destination_project_id) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |