Class: Google::Apis::GkebackupV1::RestoreChannel
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::RestoreChannel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
A RestoreChannel imposes constraints on where backups can be restored. The
RestoreChannel should be in the same project and region as the backups. The
backups can only be restored in the destination_project.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#destination_project ⇒ String
Required.
-
#destination_project_id ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RestoreChannel
constructor
A new instance of RestoreChannel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RestoreChannel
Returns a new instance of RestoreChannel.
2884 2885 2886 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2884 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when this RestoreChannel was created.
Corresponds to the JSON property createTime
2830 2831 2832 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2830 def create_time @create_time end |
#description ⇒ String
Optional. User specified descriptive string for this RestoreChannel.
Corresponds to the JSON property description
2835 2836 2837 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2835 def description @description end |
#destination_project ⇒ String
Required. Immutable. The project into which the backups will be restored. The
format is projects/projectIdor `projects/`projectNumber.
Corresponds to the JSON property destinationProject
2841 2842 2843 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2841 def destination_project @destination_project end |
#destination_project_id ⇒ String
Output only. The project_id where backups will be restored. Example Project ID:
"my-project-id". This will be an OUTPUT_ONLY field to return the project_id
of the destination project.
Corresponds to the JSON property destinationProjectId
2848 2849 2850 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2848 def destination_project_id @destination_project_id end |
#etag ⇒ String
Output only. etag is used for optimistic concurrency control as a way to
help prevent simultaneous updates of a RestoreChannel from overwriting each
other. It is strongly suggested that systems make use of the 'etag' in the
read-modify-write cycle to perform RestoreChannel updates in order to avoid
race conditions: An etag is returned in the response to GetRestoreChannel,
and systems are expected to put that etag in the request to
UpdateRestoreChannel or DeleteRestoreChannel to ensure that their change
will be applied to the same version of the resource.
Corresponds to the JSON property etag
2860 2861 2862 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2860 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. A set of custom labels supplied by user.
Corresponds to the JSON property labels
2865 2866 2867 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2865 def labels @labels end |
#name ⇒ String
Identifier. The fully qualified name of the RestoreChannel. projects/*/
locations/*/restoreChannels/*
Corresponds to the JSON property name
2871 2872 2873 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2871 def name @name end |
#uid ⇒ String
Output only. Server generated global unique identifier of UUID format.
Corresponds to the JSON property uid
2877 2878 2879 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2877 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when this RestoreChannel was last updated.
Corresponds to the JSON property updateTime
2882 2883 2884 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2882 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2889 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @destination_project = args[:destination_project] if args.key?(:destination_project) @destination_project_id = args[:destination_project_id] if args.key?(:destination_project_id) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |