Class: Google::Apis::GkebackupV1::RestoreChannel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

A RestoreChannel imposes constraints on where backups can be restored. The RestoreChannel should be in the same project and region as the backups. The backups can only be restored in the destination_project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestoreChannel

Returns a new instance of RestoreChannel.



2839
2840
2841
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2839

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when this RestoreChannel was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2785
2786
2787
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2785

def create_time
  @create_time
end

#descriptionString

Optional. User specified descriptive string for this RestoreChannel. Corresponds to the JSON property description

Returns:

  • (String)


2790
2791
2792
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2790

def description
  @description
end

#destination_projectString

Required. Immutable. The project into which the backups will be restored. The format is projects/projectIdor `projects/`projectNumber. Corresponds to the JSON property destinationProject

Returns:

  • (String)


2796
2797
2798
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2796

def destination_project
  @destination_project
end

#destination_project_idString

Output only. The project_id where backups will be restored. Example Project ID: "my-project-id". This will be an OUTPUT_ONLY field to return the project_id of the destination project. Corresponds to the JSON property destinationProjectId

Returns:

  • (String)


2803
2804
2805
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2803

def destination_project_id
  @destination_project_id
end

#etagString

Output only. etag is used for optimistic concurrency control as a way to help prevent simultaneous updates of a RestoreChannel from overwriting each other. It is strongly suggested that systems make use of the 'etag' in the read-modify-write cycle to perform RestoreChannel updates in order to avoid race conditions: An etag is returned in the response to GetRestoreChannel, and systems are expected to put that etag in the request to UpdateRestoreChannel or DeleteRestoreChannel to ensure that their change will be applied to the same version of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


2815
2816
2817
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2815

def etag
  @etag
end

#labelsHash<String,String>

Optional. A set of custom labels supplied by user. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2820
2821
2822
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2820

def labels
  @labels
end

#nameString

Identifier. The fully qualified name of the RestoreChannel. projects/*/ locations/*/restoreChannels/* Corresponds to the JSON property name

Returns:

  • (String)


2826
2827
2828
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2826

def name
  @name
end

#uidString

Output only. Server generated global unique identifier of UUID format. Corresponds to the JSON property uid

Returns:

  • (String)


2832
2833
2834
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2832

def uid
  @uid
end

#update_timeString

Output only. The timestamp when this RestoreChannel was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2837
2838
2839
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2837

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2844

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @destination_project = args[:destination_project] if args.key?(:destination_project)
  @destination_project_id = args[:destination_project_id] if args.key?(:destination_project_id)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end