Class: Google::Apis::GkebackupV1::RestoreChannel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

A RestoreChannel imposes constraints on where backups can be restored. The RestoreChannel should be in the same project and region as the backups. The backups can only be restored in the destination_project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestoreChannel

Returns a new instance of RestoreChannel.



2488
2489
2490
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2488

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when this RestoreChannel was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2434
2435
2436
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2434

def create_time
  @create_time
end

#descriptionString

Optional. User specified descriptive string for this RestoreChannel. Corresponds to the JSON property description

Returns:

  • (String)


2439
2440
2441
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2439

def description
  @description
end

#destination_projectString

Required. Immutable. The project into which the backups will be restored. The format is projects/projectIdor `projects/`projectNumber. Corresponds to the JSON property destinationProject

Returns:

  • (String)


2445
2446
2447
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2445

def destination_project
  @destination_project
end

#destination_project_idString

Output only. The project_id where backups will be restored. Example Project ID: "my-project-id". This will be an OUTPUT_ONLY field to return the project_id of the destination project. Corresponds to the JSON property destinationProjectId

Returns:

  • (String)


2452
2453
2454
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2452

def destination_project_id
  @destination_project_id
end

#etagString

Output only. etag is used for optimistic concurrency control as a way to help prevent simultaneous updates of a RestoreChannel from overwriting each other. It is strongly suggested that systems make use of the 'etag' in the read-modify-write cycle to perform RestoreChannel updates in order to avoid race conditions: An etag is returned in the response to GetRestoreChannel, and systems are expected to put that etag in the request to UpdateRestoreChannel or DeleteRestoreChannel to ensure that their change will be applied to the same version of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


2464
2465
2466
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2464

def etag
  @etag
end

#labelsHash<String,String>

Optional. A set of custom labels supplied by user. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2469
2470
2471
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2469

def labels
  @labels
end

#nameString

Identifier. The fully qualified name of the RestoreChannel. projects/*/ locations/*/restoreChannels/* Corresponds to the JSON property name

Returns:

  • (String)


2475
2476
2477
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2475

def name
  @name
end

#uidString

Output only. Server generated global unique identifier of UUID format. Corresponds to the JSON property uid

Returns:

  • (String)


2481
2482
2483
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2481

def uid
  @uid
end

#update_timeString

Output only. The timestamp when this RestoreChannel was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2486
2487
2488
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2486

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2493

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @destination_project = args[:destination_project] if args.key?(:destination_project)
  @destination_project_id = args[:destination_project_id] if args.key?(:destination_project_id)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end