Class: Google::Apis::GkebackupV1::RestorePlan

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

The configuration of a potential series of Restore operations to be performed against Backups belong to a particular BackupPlan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestorePlan

Returns a new instance of RestorePlan.



3091
3092
3093
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3091

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_planString

Required. Immutable. A reference to the BackupPlan from which Backups may be used as the source for Restores created via this RestorePlan. Format: projects/*/locations/*/backupPlans/*. Corresponds to the JSON property backupPlan

Returns:

  • (String)


3011
3012
3013
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3011

def backup_plan
  @backup_plan
end

#clusterString

Required. Immutable. The target cluster into which Restores created via this RestorePlan will restore data. NOTE: the cluster's region must be the same as the RestorePlan. Valid formats: - projects/*/locations/*/clusters/* - projects/*/zones/*/clusters/* Corresponds to the JSON property cluster

Returns:

  • (String)


3019
3020
3021
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3019

def cluster
  @cluster
end

#create_timeString

Output only. The timestamp when this RestorePlan resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3024
3025
3026
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3024

def create_time
  @create_time
end

#descriptionString

Optional. User specified descriptive string for this RestorePlan. Corresponds to the JSON property description

Returns:

  • (String)


3029
3030
3031
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3029

def description
  @description
end

#etagString

Output only. etag is used for optimistic concurrency control as a way to help prevent simultaneous updates of a restore from overwriting each other. It is strongly suggested that systems make use of the etag in the read-modify- write cycle to perform restore updates in order to avoid race conditions: An etag is returned in the response to GetRestorePlan, and systems are expected to put that etag in the request to UpdateRestorePlan or DeleteRestorePlan to ensure that their change will be applied to the same version of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


3041
3042
3043
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3041

def etag
  @etag
end

#labelsHash<String,String>

Optional. A set of custom labels supplied by user. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3046
3047
3048
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3046

def labels
  @labels
end

#nameString

Output only. Identifier. The full name of the RestorePlan resource. Format: projects/*/locations/*/restorePlans/*. Corresponds to the JSON property name

Returns:

  • (String)


3052
3053
3054
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3052

def name
  @name
end

#restore_channelString

Output only. The fully qualified name of the RestoreChannel to be used to create a RestorePlan. This field is set only if the backup_plan is in a different project than the RestorePlan. Format: projects/*/locations/*/ restoreChannels/* Corresponds to the JSON property restoreChannel

Returns:

  • (String)


3060
3061
3062
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3060

def restore_channel
  @restore_channel
end

#restore_configGoogle::Apis::GkebackupV1::RestoreConfig

Configuration of a restore. Corresponds to the JSON property restoreConfig



3065
3066
3067
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3065

def restore_config
  @restore_config
end

#stateString

Output only. State of the RestorePlan. This State field reflects the various stages a RestorePlan can be in during the Create operation. Corresponds to the JSON property state

Returns:

  • (String)


3071
3072
3073
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3071

def state
  @state
end

#state_reasonString

Output only. Human-readable description of why RestorePlan is in the current state. This field is only meant for human readability and should not be used programmatically as this field is not guaranteed to be consistent. Corresponds to the JSON property stateReason

Returns:

  • (String)


3078
3079
3080
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3078

def state_reason
  @state_reason
end

#uidString

Output only. Server generated global unique identifier of UUID format. Corresponds to the JSON property uid

Returns:

  • (String)


3084
3085
3086
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3084

def uid
  @uid
end

#update_timeString

Output only. The timestamp when this RestorePlan resource was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3089
3090
3091
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3089

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
3108
3109
3110
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3096

def update!(**args)
  @backup_plan = args[:backup_plan] if args.key?(:backup_plan)
  @cluster = args[:cluster] if args.key?(:cluster)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @restore_channel = args[:restore_channel] if args.key?(:restore_channel)
  @restore_config = args[:restore_config] if args.key?(:restore_config)
  @state = args[:state] if args.key?(:state)
  @state_reason = args[:state_reason] if args.key?(:state_reason)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end