Class: Google::Apis::GkebackupV1::RestorePlanBinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

A RestorePlanBinding binds a RestorePlan with a RestoreChannel. This resource is created automatically when a RestorePlan is created using a RestoreChannel. This also serves as a holder for cross-project fields that need to be displayed in the current project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestorePlanBinding

Returns a new instance of RestorePlanBinding.



3205
3206
3207
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3205

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_planString

Output only. The fully qualified name of the BackupPlan bound to the specified RestorePlan. projects/*/locations/*/backukpPlans/backup_plan` Corresponds to the JSON propertybackupPlan`

Returns:

  • (String)


3163
3164
3165
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3163

def backup_plan
  @backup_plan
end

#create_timeString

Output only. The timestamp when this binding was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3168
3169
3170
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3168

def create_time
  @create_time
end

#etagString

Output only. etag is used for optimistic concurrency control as a way to help prevent simultaneous updates of a RestorePlanBinding from overwriting each other. It is strongly suggested that systems make use of the 'etag' in the read-modify-write cycle to perform RestorePlanBinding updates in order to avoid race conditions: An etag is returned in the response to GetRestorePlanBinding, and systems are expected to put that etag in the request to UpdateRestorePlanBinding or DeleteRestorePlanBinding to ensure that their change will be applied to the same version of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


3180
3181
3182
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3180

def etag
  @etag
end

#nameString

Identifier. The fully qualified name of the RestorePlanBinding. projects/*/ locations/*/restoreChannels/*/restorePlanBindings/* Corresponds to the JSON property name

Returns:

  • (String)


3186
3187
3188
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3186

def name
  @name
end

#restore_planString

Output only. The fully qualified name of the RestorePlan bound to this RestoreChannel. projects/*/locations/*/restorePlans/restore_plan` Corresponds to the JSON propertyrestorePlan`

Returns:

  • (String)


3192
3193
3194
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3192

def restore_plan
  @restore_plan
end

#uidString

Output only. Server generated global unique identifier of UUID4 Corresponds to the JSON property uid

Returns:

  • (String)


3198
3199
3200
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3198

def uid
  @uid
end

#update_timeString

Output only. The timestamp when this binding was created. Corresponds to the JSON property updateTime

Returns:

  • (String)


3203
3204
3205
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3203

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3210
3211
3212
3213
3214
3215
3216
3217
3218
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3210

def update!(**args)
  @backup_plan = args[:backup_plan] if args.key?(:backup_plan)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @restore_plan = args[:restore_plan] if args.key?(:restore_plan)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end