Class: Google::Apis::GkebackupV1::RestorePlanBinding
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::RestorePlanBinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
A RestorePlanBinding binds a RestorePlan with a RestoreChannel. This resource is created automatically when a RestorePlan is created using a RestoreChannel. This also serves as a holder for cross-project fields that need to be displayed in the current project.
Instance Attribute Summary collapse
-
#backup_plan ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#restore_plan ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RestorePlanBinding
constructor
A new instance of RestorePlanBinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RestorePlanBinding
Returns a new instance of RestorePlanBinding.
2815 2816 2817 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2815 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_plan ⇒ String
Output only. The fully qualified name of the BackupPlan bound to the specified
RestorePlan. projects/*/locations/*/backukpPlans/backup_plan`
Corresponds to the JSON propertybackupPlan`
2773 2774 2775 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2773 def backup_plan @backup_plan end |
#create_time ⇒ String
Output only. The timestamp when this binding was created.
Corresponds to the JSON property createTime
2778 2779 2780 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2778 def create_time @create_time end |
#etag ⇒ String
Output only. etag is used for optimistic concurrency control as a way to
help prevent simultaneous updates of a RestorePlanBinding from overwriting
each other. It is strongly suggested that systems make use of the 'etag' in
the read-modify-write cycle to perform RestorePlanBinding updates in order to
avoid race conditions: An etag is returned in the response to
GetRestorePlanBinding, and systems are expected to put that etag in the
request to UpdateRestorePlanBinding or DeleteRestorePlanBinding to ensure
that their change will be applied to the same version of the resource.
Corresponds to the JSON property etag
2790 2791 2792 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2790 def etag @etag end |
#name ⇒ String
Identifier. The fully qualified name of the RestorePlanBinding. projects/*/
locations/*/restoreChannels/*/restorePlanBindings/*
Corresponds to the JSON property name
2796 2797 2798 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2796 def name @name end |
#restore_plan ⇒ String
Output only. The fully qualified name of the RestorePlan bound to this
RestoreChannel. projects/*/locations/*/restorePlans/restore_plan`
Corresponds to the JSON propertyrestorePlan`
2802 2803 2804 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2802 def restore_plan @restore_plan end |
#uid ⇒ String
Output only. Server generated global unique identifier of UUID4
Corresponds to the JSON property uid
2808 2809 2810 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2808 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when this binding was created.
Corresponds to the JSON property updateTime
2813 2814 2815 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2813 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2820 2821 2822 2823 2824 2825 2826 2827 2828 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2820 def update!(**args) @backup_plan = args[:backup_plan] if args.key?(:backup_plan) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @restore_plan = args[:restore_plan] if args.key?(:restore_plan) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |