Class: Google::Apis::GkebackupV1::RetentionPolicyDetails
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::RetentionPolicyDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
RetentionPolicyDetails defines a Backup retention policy for a BackupPlan.
Instance Attribute Summary collapse
-
#backup_delete_lock_days ⇒ Fixnum
Optional.
-
#backup_retain_days ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RetentionPolicyDetails
constructor
A new instance of RetentionPolicyDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RetentionPolicyDetails
Returns a new instance of RetentionPolicyDetails.
2904 2905 2906 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2904 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_delete_lock_days ⇒ Fixnum
Optional. Minimum age for Backups created via this BackupPlan (in days). This
field MUST be an integer value between 0-90 (inclusive). A Backup created
under this BackupPlan will NOT be deletable until it reaches Backup's (
create_time + backup_delete_lock_days). Updating this field of a BackupPlan
does NOT affect existing Backups under it. Backups created AFTER a successful
update will inherit the new value. Default: 0 (no delete blocking)
Corresponds to the JSON property backupDeleteLockDays
2892 2893 2894 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2892 def backup_delete_lock_days @backup_delete_lock_days end |
#backup_retain_days ⇒ Fixnum
Optional. The default maximum age of a Backup created via this BackupPlan.
This field MUST be an integer value >= 0 and <= 365. If specified, a Backup
created under this BackupPlan will be automatically deleted after its age
reaches (create_time + backup_retain_days). If not specified, Backups created
under this BackupPlan will NOT be subject to automatic deletion. Default: 0 (
no automatic deletion)
Corresponds to the JSON property backupRetainDays
2902 2903 2904 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2902 def backup_retain_days @backup_retain_days end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2909 2910 2911 2912 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2909 def update!(**args) @backup_delete_lock_days = args[:backup_delete_lock_days] if args.key?(:backup_delete_lock_days) @backup_retain_days = args[:backup_retain_days] if args.key?(:backup_retain_days) end |