Class: Google::Apis::GkebackupV1::RpoConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::RpoConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
Defines RPO scheduling configuration for automatically creating Backups via this BackupPlan.
Instance Attribute Summary collapse
-
#exclusion_windows ⇒ Array<Google::Apis::GkebackupV1::ExclusionWindow>
Optional.
-
#target_rpo_minutes ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RpoConfig
constructor
A new instance of RpoConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RpoConfig
Returns a new instance of RpoConfig.
2939 2940 2941 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2939 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exclusion_windows ⇒ Array<Google::Apis::GkebackupV1::ExclusionWindow>
Optional. User specified time windows during which backup can NOT happen for
this BackupPlan - backups should start and finish outside of any given
exclusion window. Note: backup jobs will be scheduled to start and finish
outside the duration of the window as much as possible, but running jobs will
not get canceled when it runs into the window. All the time and date values in
exclusion_windows entry in the API are in UTC. We only allow <=1 recurrence (
daily or weekly) exclusion window for a BackupPlan while no restriction on
number of single occurrence windows.
Corresponds to the JSON property exclusionWindows
2930 2931 2932 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2930 def exclusion_windows @exclusion_windows end |
#target_rpo_minutes ⇒ Fixnum
Required. Defines the target RPO for the BackupPlan in minutes, which means
the target maximum data loss in time that is acceptable for this BackupPlan.
This must be at least 60, i.e., 1 hour, and at most 86400, i.e., 60 days.
Corresponds to the JSON property targetRpoMinutes
2937 2938 2939 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2937 def target_rpo_minutes @target_rpo_minutes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2944 2945 2946 2947 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2944 def update!(**args) @exclusion_windows = args[:exclusion_windows] if args.key?(:exclusion_windows) @target_rpo_minutes = args[:target_rpo_minutes] if args.key?(:target_rpo_minutes) end |