Class: Google::Apis::GkebackupV1::Schedule
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::Schedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
Defines scheduling parameters for automatically creating Backups via this BackupPlan.
Instance Attribute Summary collapse
-
#cron_schedule ⇒ String
Optional.
-
#next_scheduled_backup_time ⇒ String
Output only.
-
#paused ⇒ Boolean
(also: #paused?)
Optional.
-
#rpo_config ⇒ Google::Apis::GkebackupV1::RpoConfig
Defines RPO scheduling configuration for automatically creating Backups via this BackupPlan.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schedule
constructor
A new instance of Schedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schedule
Returns a new instance of Schedule.
2983 2984 2985 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2983 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cron_schedule ⇒ String
Optional. A standard cron string that
defines a repeating schedule for creating Backups via this BackupPlan. This is
mutually exclusive with the rpo_config field since at most one schedule can be
defined for a BackupPlan. If this is defined, then backup_retain_days must
also be defined. Default (empty): no automatic backup creation will occur.
Corresponds to the JSON property cronSchedule
2962 2963 2964 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2962 def cron_schedule @cron_schedule end |
#next_scheduled_backup_time ⇒ String
Output only. Start time of next scheduled backup under this BackupPlan by
either cron_schedule or rpo config.
Corresponds to the JSON property nextScheduledBackupTime
2968 2969 2970 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2968 def next_scheduled_backup_time @next_scheduled_backup_time end |
#paused ⇒ Boolean Also known as: paused?
Optional. This flag denotes whether automatic Backup creation is paused for
this BackupPlan. Default: False
Corresponds to the JSON property paused
2974 2975 2976 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2974 def paused @paused end |
#rpo_config ⇒ Google::Apis::GkebackupV1::RpoConfig
Defines RPO scheduling configuration for automatically creating Backups via
this BackupPlan.
Corresponds to the JSON property rpoConfig
2981 2982 2983 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2981 def rpo_config @rpo_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2988 2989 2990 2991 2992 2993 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 2988 def update!(**args) @cron_schedule = args[:cron_schedule] if args.key?(:cron_schedule) @next_scheduled_backup_time = args[:next_scheduled_backup_time] if args.key?(:next_scheduled_backup_time) @paused = args[:paused] if args.key?(:paused) @rpo_config = args[:rpo_config] if args.key?(:rpo_config) end |