Class: Google::Apis::GkebackupV1::TransformationRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

A transformation rule to be applied against Kubernetes resources as they are selected for restoration from a Backup. A rule contains both filtering logic ( which resources are subject to transform) and transformation logic.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TransformationRule

Returns a new instance of TransformationRule.



3693
3694
3695
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3693

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. The description is a user specified string description of the transformation rule. Corresponds to the JSON property description

Returns:

  • (String)


3676
3677
3678
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3676

def description
  @description
end

#field_actionsArray<Google::Apis::GkebackupV1::TransformationRuleAction>

Required. A list of transformation rule actions to take against candidate resources. Actions are executed in order defined - this order matters, as they could potentially interfere with each other and the first operation could affect the outcome of the second operation. Corresponds to the JSON property fieldActions



3684
3685
3686
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3684

def field_actions
  @field_actions
end

#resource_filterGoogle::Apis::GkebackupV1::ResourceFilter

ResourceFilter specifies matching criteria to limit the scope of a change to a specific set of kubernetes resources that are selected for restoration from a backup. Corresponds to the JSON property resourceFilter



3691
3692
3693
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3691

def resource_filter
  @resource_filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3698
3699
3700
3701
3702
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3698

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @field_actions = args[:field_actions] if args.key?(:field_actions)
  @resource_filter = args[:resource_filter] if args.key?(:resource_filter)
end