Class: Google::Apis::GkebackupV1::TroubleshootingInfo
- Inherits:
-
Object
- Object
- Google::Apis::GkebackupV1::TroubleshootingInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb
Overview
Stores information about troubleshooting doc for debugging a particular state of an operation (eg - backup/restore). This will be used by the end user to debug their operation failure scenario easily.
Instance Attribute Summary collapse
-
#state_reason_code ⇒ String
Output only.
-
#state_reason_uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TroubleshootingInfo
constructor
A new instance of TroubleshootingInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TroubleshootingInfo
Returns a new instance of TroubleshootingInfo.
3299 3300 3301 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3299 def initialize(**args) update!(**args) end |
Instance Attribute Details
#state_reason_code ⇒ String
Output only. Unique code for each backup/restore operation failure message
which helps user identify the failure.
Corresponds to the JSON property stateReasonCode
3291 3292 3293 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3291 def state_reason_code @state_reason_code end |
#state_reason_uri ⇒ String
Output only. URL for the troubleshooting doc which will help the user fix the
failing backup/restore operation.
Corresponds to the JSON property stateReasonUri
3297 3298 3299 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3297 def state_reason_uri @state_reason_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3304 3305 3306 3307 |
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3304 def update!(**args) @state_reason_code = args[:state_reason_code] if args.key?(:state_reason_code) @state_reason_uri = args[:state_reason_uri] if args.key?(:state_reason_uri) end |