Class: Google::Apis::GkebackupV1::VolumeBackup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Represents the backup of a specific persistent volume as a component of a Backup - both the record of the operation and a pointer to the underlying storage-specific artifacts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VolumeBackup

Returns a new instance of VolumeBackup.



3885
3886
3887
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3885

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#complete_timeString

Output only. The timestamp when the associated underlying volume backup operation completed. Corresponds to the JSON property completeTime

Returns:

  • (String)


3797
3798
3799
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3797

def complete_time
  @complete_time
end

#create_timeString

Output only. The timestamp when this VolumeBackup resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3802
3803
3804
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3802

def create_time
  @create_time
end

#disk_size_bytesFixnum

Output only. The minimum size of the disk to which this VolumeBackup can be restored. Corresponds to the JSON property diskSizeBytes

Returns:

  • (Fixnum)


3808
3809
3810
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3808

def disk_size_bytes
  @disk_size_bytes
end

#etagString

Output only. etag is used for optimistic concurrency control as a way to help prevent simultaneous updates of a volume backup from overwriting each other. It is strongly suggested that systems make use of the etag in the read-modify-write cycle to perform volume backup updates in order to avoid race conditions. Corresponds to the JSON property etag

Returns:

  • (String)


3817
3818
3819
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3817

def etag
  @etag
end

#formatString

Output only. The format used for the volume backup. Corresponds to the JSON property format

Returns:

  • (String)


3822
3823
3824
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3822

def format
  @format
end

#nameString

Output only. The full name of the VolumeBackup resource. Format: projects/*/ locations/*/backupPlans/*/backups/*/volumeBackups/*. Corresponds to the JSON property name

Returns:

  • (String)


3828
3829
3830
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3828

def name
  @name
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


3833
3834
3835
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3833

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


3839
3840
3841
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3839

def satisfies_pzs
  @satisfies_pzs
end

#source_pvcGoogle::Apis::GkebackupV1::NamespacedName

A reference to a namespaced resource in Kubernetes. Corresponds to the JSON property sourcePvc



3845
3846
3847
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3845

def source_pvc
  @source_pvc
end

#stateString

Output only. The current state of this VolumeBackup. Corresponds to the JSON property state

Returns:

  • (String)


3850
3851
3852
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3850

def state
  @state
end

#state_messageString

Output only. A human readable message explaining why the VolumeBackup is in its current state. This field is only meant for human consumption and should not be used programmatically as this field is not guaranteed to be consistent. Corresponds to the JSON property stateMessage

Returns:

  • (String)


3857
3858
3859
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3857

def state_message
  @state_message
end

#storage_bytesFixnum

Output only. The aggregate size of the underlying artifacts associated with this VolumeBackup in the backup storage. This may change over time when multiple backups of the same volume share the same backup storage location. In particular, this is likely to increase in size when the immediately preceding backup of the same volume is deleted. Corresponds to the JSON property storageBytes

Returns:

  • (Fixnum)


3866
3867
3868
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3866

def storage_bytes
  @storage_bytes
end

#uidString

Output only. Server generated global unique identifier of UUID format. Corresponds to the JSON property uid

Returns:

  • (String)


3872
3873
3874
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3872

def uid
  @uid
end

#update_timeString

Output only. The timestamp when this VolumeBackup resource was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3877
3878
3879
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3877

def update_time
  @update_time
end

#volume_backup_handleString

Output only. A storage system-specific opaque handle to the underlying volume backup. Corresponds to the JSON property volumeBackupHandle

Returns:

  • (String)


3883
3884
3885
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3883

def volume_backup_handle
  @volume_backup_handle
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3890
3891
3892
3893
3894
3895
3896
3897
3898
3899
3900
3901
3902
3903
3904
3905
3906
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3890

def update!(**args)
  @complete_time = args[:complete_time] if args.key?(:complete_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @disk_size_bytes = args[:disk_size_bytes] if args.key?(:disk_size_bytes)
  @etag = args[:etag] if args.key?(:etag)
  @format = args[:format] if args.key?(:format)
  @name = args[:name] if args.key?(:name)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @source_pvc = args[:source_pvc] if args.key?(:source_pvc)
  @state = args[:state] if args.key?(:state)
  @state_message = args[:state_message] if args.key?(:state_message)
  @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @volume_backup_handle = args[:volume_backup_handle] if args.key?(:volume_backup_handle)
end