Class: Google::Apis::GkebackupV1::VolumeBackup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkebackup_v1/classes.rb,
lib/google/apis/gkebackup_v1/representations.rb,
lib/google/apis/gkebackup_v1/representations.rb

Overview

Represents the backup of a specific persistent volume as a component of a Backup - both the record of the operation and a pointer to the underlying storage-specific artifacts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VolumeBackup

Returns a new instance of VolumeBackup.



3408
3409
3410
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3408

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#complete_timeString

Output only. The timestamp when the associated underlying volume backup operation completed. Corresponds to the JSON property completeTime

Returns:

  • (String)


3320
3321
3322
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3320

def complete_time
  @complete_time
end

#create_timeString

Output only. The timestamp when this VolumeBackup resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3325
3326
3327
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3325

def create_time
  @create_time
end

#disk_size_bytesFixnum

Output only. The minimum size of the disk to which this VolumeBackup can be restored. Corresponds to the JSON property diskSizeBytes

Returns:

  • (Fixnum)


3331
3332
3333
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3331

def disk_size_bytes
  @disk_size_bytes
end

#etagString

Output only. etag is used for optimistic concurrency control as a way to help prevent simultaneous updates of a volume backup from overwriting each other. It is strongly suggested that systems make use of the etag in the read-modify-write cycle to perform volume backup updates in order to avoid race conditions. Corresponds to the JSON property etag

Returns:

  • (String)


3340
3341
3342
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3340

def etag
  @etag
end

#formatString

Output only. The format used for the volume backup. Corresponds to the JSON property format

Returns:

  • (String)


3345
3346
3347
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3345

def format
  @format
end

#nameString

Output only. The full name of the VolumeBackup resource. Format: projects/*/ locations/*/backupPlans/*/backups/*/volumeBackups/*. Corresponds to the JSON property name

Returns:

  • (String)


3351
3352
3353
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3351

def name
  @name
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


3356
3357
3358
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3356

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


3362
3363
3364
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3362

def satisfies_pzs
  @satisfies_pzs
end

#source_pvcGoogle::Apis::GkebackupV1::NamespacedName

A reference to a namespaced resource in Kubernetes. Corresponds to the JSON property sourcePvc



3368
3369
3370
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3368

def source_pvc
  @source_pvc
end

#stateString

Output only. The current state of this VolumeBackup. Corresponds to the JSON property state

Returns:

  • (String)


3373
3374
3375
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3373

def state
  @state
end

#state_messageString

Output only. A human readable message explaining why the VolumeBackup is in its current state. This field is only meant for human consumption and should not be used programmatically as this field is not guaranteed to be consistent. Corresponds to the JSON property stateMessage

Returns:

  • (String)


3380
3381
3382
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3380

def state_message
  @state_message
end

#storage_bytesFixnum

Output only. The aggregate size of the underlying artifacts associated with this VolumeBackup in the backup storage. This may change over time when multiple backups of the same volume share the same backup storage location. In particular, this is likely to increase in size when the immediately preceding backup of the same volume is deleted. Corresponds to the JSON property storageBytes

Returns:

  • (Fixnum)


3389
3390
3391
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3389

def storage_bytes
  @storage_bytes
end

#uidString

Output only. Server generated global unique identifier of UUID format. Corresponds to the JSON property uid

Returns:

  • (String)


3395
3396
3397
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3395

def uid
  @uid
end

#update_timeString

Output only. The timestamp when this VolumeBackup resource was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3400
3401
3402
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3400

def update_time
  @update_time
end

#volume_backup_handleString

Output only. A storage system-specific opaque handle to the underlying volume backup. Corresponds to the JSON property volumeBackupHandle

Returns:

  • (String)


3406
3407
3408
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3406

def volume_backup_handle
  @volume_backup_handle
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3413
3414
3415
3416
3417
3418
3419
3420
3421
3422
3423
3424
3425
3426
3427
3428
3429
# File 'lib/google/apis/gkebackup_v1/classes.rb', line 3413

def update!(**args)
  @complete_time = args[:complete_time] if args.key?(:complete_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @disk_size_bytes = args[:disk_size_bytes] if args.key?(:disk_size_bytes)
  @etag = args[:etag] if args.key?(:etag)
  @format = args[:format] if args.key?(:format)
  @name = args[:name] if args.key?(:name)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @source_pvc = args[:source_pvc] if args.key?(:source_pvc)
  @state = args[:state] if args.key?(:state)
  @state_message = args[:state_message] if args.key?(:state_message)
  @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @volume_backup_handle = args[:volume_backup_handle] if args.key?(:volume_backup_handle)
end